@@ -15,7 +15,7 @@ if [ -z "$VERSION" ]; then
     exit 1
 fi
 
-if [ -z "$REPO" ]; then
+if [ -z "$REPOPATH" ]; then
     REPOPATH="https://github.com/simplesamlphp/simplesamlphp.git"
 fi
 
@@ -36,30 +36,38 @@ cd $TARGET
 git checkout $TAG
 cd ..
 
-# Use composer only on newer versions that have a composer.json
-if [ -f "$TARGET/composer.json" ]; then
-    if [ ! -x "$TARGET/composer.phar" ]; then
-        curl -sS https://getcomposer.org/installer | php -- --install-dir=$TARGET
-    fi
-
-    # Install dependencies (without vcs history or dev tools)
-    php "$TARGET/composer.phar" install --no-dev --prefer-dist -o -d "$TARGET"
+if [ ! -x "$TARGET/composer.phar" ]; then
+    curl -sS https://getcomposer.org/installer | php -- --install-dir=$TARGET
 fi
 
-mkdir -p "$TARGET/config" "$TARGET/metadata" "$TARGET/cert" "$TARGET/log"
+# Set the version in composer.json
+php "$TARGET/composer.phar" config version "$VERSION" -d "$TARGET"
+
+# Install dependencies (without vcs history or dev tools)
+php "$TARGET/composer.phar" install --no-dev --prefer-dist -o -d "$TARGET"
+
+cd $TARGET 
+npm install
+npm audit fix
+npm run build
+cd ..
+
+mkdir -p "$TARGET/config" "$TARGET/metadata" "$TARGET/cert" "$TARGET/log" "$TARGET/data"
 cp -rv "$TARGET/config-templates/"* "$TARGET/config/"
 cp -rv "$TARGET/metadata-templates/"* "$TARGET/metadata/"
 rm -rf "$TARGET/.git"
+rm -rf "$TARGET/node_modules"
+rm "$TARGET/www/assets/js/stylesheet.js"*
 rm "$TARGET/.coveralls.yml"
+rm "$TARGET/.editorconfig"
+rm "$TARGET/.gitattributes"
+rm "$TARGET/.php_cs.dist"
 rm "$TARGET/.travis.yml"
 rm "$TARGET/psalm.xml"
 rm "$TARGET"/{,modules}/.gitignore
-rm "$TARGET/.gitattributes"
 rm "$TARGET"/{cache,config,metadata,locales}/.gitkeep
-rm "$TARGET/.editorconfig"
 rm "$TARGET/composer.phar"
 tar --owner 0 --group 0 -cvzf "$TARGET.tar.gz" "$TARGET"
 rm -rf "$TARGET"
 
 echo "Created: /tmp/$TARGET.tar.gz"
-
