@@ -1,6 +1,6 @@
 <?php
 
-use SimpleSAML\Auth\SourceFactory;
+namespace SimpleSAML\Auth;
 
 /**
  * This class defines a base class for authentication source.
@@ -10,10 +10,9 @@ use SimpleSAML\Auth\SourceFactory;
  * @author Olav Morken, UNINETT AS.
  * @package SimpleSAMLphp
  */
-abstract class SimpleSAML_Auth_Source
+
+abstract class Source
 {
-
-
     /**
      * The authentication source identifier. This identifier can be used to look up this object, for example when
      * returning from a login form.
@@ -47,16 +46,16 @@ abstract class SimpleSAML_Auth_Source
      *
      * @param string $type The type of the authentication source.
      *
-     * @return SimpleSAML_Auth_Source[]  Array of SimpleSAML_Auth_Source objects of the specified type.
+     * @return Source[]  Array of \SimpleSAML\Auth\Source objects of the specified type.
      * @throws Exception If the authentication source is invalid.
      */
     public static function getSourcesOfType($type)
     {
         assert(is_string($type));
 
-        $config = SimpleSAML_Configuration::getConfig('authsources.php');
+        $config = \SimpleSAML\Configuration::getConfig('authsources.php');
 
-        $ret = array();
+        $ret = [];
 
         $sources = $config->getOptions();
         foreach ($sources as $id) {
@@ -116,7 +115,7 @@ abstract class SimpleSAML_Auth_Source
         assert(isset($state['ReturnCallback']));
 
         // the default implementation just copies over the previous authentication data
-        $session = SimpleSAML_Session::getSessionFromRequest();
+        $session = \SimpleSAML\Session::getSessionFromRequest();
         $data = $session->getAuthState($this->authId);
         foreach ($data as $k => $v) {
             $state[$k] = $v;
@@ -138,7 +137,7 @@ abstract class SimpleSAML_Auth_Source
         assert(is_array($state));
         assert(array_key_exists('LoginCompletedHandler', $state));
 
-        SimpleSAML_Auth_State::deleteState($state);
+        State::deleteState($state);
 
         $func = $state['LoginCompletedHandler'];
         assert(is_callable($func));
@@ -161,42 +160,42 @@ abstract class SimpleSAML_Auth_Source
      * @param array $params Extra information about the login. Different authentication requestors may provide different
      * information. Optional, will default to an empty array.
      */
-    public function initLogin($return, $errorURL = null, array $params = array())
+    public function initLogin($return, $errorURL = null, array $params = [])
     {
         assert(is_string($return) || is_array($return));
         assert(is_string($errorURL) || $errorURL === null);
 
-        $state = array_merge($params, array(
-            'SimpleSAML_Auth_Default.id' => $this->authId, // TODO: remove in 2.0
-            'SimpleSAML_Auth_Source.id' => $this->authId,
-            'SimpleSAML_Auth_Default.Return' => $return, // TODO: remove in 2.0
-            'SimpleSAML_Auth_Source.Return' => $return,
-            'SimpleSAML_Auth_Default.ErrorURL' => $errorURL, // TODO: remove in 2.0
-            'SimpleSAML_Auth_Source.ErrorURL' => $errorURL,
-            'LoginCompletedHandler' => array(get_class(), 'loginCompleted'),
-            'LogoutCallback' => array(get_class(), 'logoutCallback'),
-            'LogoutCallbackState' => array(
-                'SimpleSAML_Auth_Default.logoutSource' => $this->authId, // TODO: remove in 2.0
-                'SimpleSAML_Auth_Source.logoutSource' => $this->authId,
-            ),
-        ));
+        $state = array_merge($params, [
+            '\SimpleSAML\Auth\DefaultAuth.id' => $this->authId, // TODO: remove in 2.0
+            '\SimpleSAML\Auth\Source.id' => $this->authId,
+            '\SimpleSAML\Auth\DefaultAuth.Return' => $return, // TODO: remove in 2.0
+            '\SimpleSAML\Auth\Source.Return' => $return,
+            '\SimpleSAML\Auth\DefaultAuth.ErrorURL' => $errorURL, // TODO: remove in 2.0
+            '\SimpleSAML\Auth\Source.ErrorURL' => $errorURL,
+            'LoginCompletedHandler' => [get_class(), 'loginCompleted'],
+            'LogoutCallback' => [get_class(), 'logoutCallback'],
+            'LogoutCallbackState' => [
+                '\SimpleSAML\Auth\DefaultAuth.logoutSource' => $this->authId, // TODO: remove in 2.0
+                '\SimpleSAML\Auth\Source.logoutSource' => $this->authId,
+            ],
+        ]);
 
         if (is_string($return)) {
-            $state['SimpleSAML_Auth_Default.ReturnURL'] = $return; // TODO: remove in 2.0
-            $state['SimpleSAML_Auth_Source.ReturnURL'] = $return;
+            $state['\SimpleSAML\Auth\DefaultAuth.ReturnURL'] = $return; // TODO: remove in 2.0
+            $state['\SimpleSAML\Auth\Source.ReturnURL'] = $return;
         }
 
         if ($errorURL !== null) {
-            $state[SimpleSAML_Auth_State::EXCEPTION_HANDLER_URL] = $errorURL;
+            $state[State::EXCEPTION_HANDLER_URL] = $errorURL;
         }
 
         try {
             $this->authenticate($state);
-        } catch (SimpleSAML_Error_Exception $e) {
-            SimpleSAML_Auth_State::throwException($state, $e);
-        } catch (Exception $e) {
-            $e = new SimpleSAML_Error_UnserializableException($e);
-            SimpleSAML_Auth_State::throwException($state, $e);
+        } catch (\SimpleSAML\Error\Exception $e) {
+            State::throwException($state, $e);
+        } catch (\Exception $e) {
+            $e = new \SimpleSAML\Error\UnserializableException($e);
+            State::throwException($state, $e);
         }
         self::loginCompleted($state);
     }
@@ -212,19 +211,20 @@ abstract class SimpleSAML_Auth_Source
     public static function loginCompleted($state)
     {
         assert(is_array($state));
-        assert(array_key_exists('SimpleSAML_Auth_Source.Return', $state));
-        assert(array_key_exists('SimpleSAML_Auth_Source.id', $state));
+        assert(array_key_exists('\SimpleSAML\Auth\Source.Return', $state));
+        assert(array_key_exists('\SimpleSAML\Auth\Source.id', $state));
         assert(array_key_exists('Attributes', $state));
         assert(!array_key_exists('LogoutState', $state) || is_array($state['LogoutState']));
 
-        $return = $state['SimpleSAML_Auth_Source.Return'];
+        $return = $state['\SimpleSAML\Auth\Source.Return'];
 
         // save session state
-        $session = SimpleSAML_Session::getSessionFromRequest();
-        $authId = $state['SimpleSAML_Auth_Source.id'];
-        $session->doLogin($authId, SimpleSAML_Auth_State::getPersistentAuthData($state));
+        $session = \SimpleSAML\Session::getSessionFromRequest();
+        $authId = $state['\SimpleSAML\Auth\Source.id'];
+        $session->doLogin($authId, State::getPersistentAuthData($state));
 
-        if (is_string($return)) { // redirect...
+        if (is_string($return)) {
+            // redirect...
             \SimpleSAML\Utils\HTTP::redirectTrustedURL($return);
         } else {
             call_user_func($return, $state);
@@ -267,7 +267,7 @@ abstract class SimpleSAML_Auth_Source
         assert(is_array($state));
         assert(array_key_exists('LogoutCompletedHandler', $state));
 
-        SimpleSAML_Auth_State::deleteState($state);
+        State::deleteState($state);
 
         $func = $state['LogoutCompletedHandler'];
         assert(is_callable($func));
@@ -286,8 +286,8 @@ abstract class SimpleSAML_Auth_Source
      * @param string $authId The authentication source identifier.
      * @param array  $config The configuration.
      *
-     * @return SimpleSAML_Auth_Source The parsed authentication source.
-     * @throws Exception If the authentication source is invalid.
+     * @return Source The parsed authentication source.
+     * @throws \Exception If the authentication source is invalid.
      */
     private static function parseAuthSource($authId, $config)
     {
@@ -297,21 +297,25 @@ abstract class SimpleSAML_Auth_Source
         self::validateSource($config, $authId);
 
         $id = $config[0];
-        $info = array('AuthId' => $authId);
+        $info = ['AuthId' => $authId];
         $authSource = null;
 
         unset($config[0]);
 
         try {
             // Check whether or not there's a factory responsible for instantiating our Auth Source instance
-            $factoryClass = SimpleSAML\Module::resolveClass($id, 'Auth_Source_Factory', 'SimpleSAML\Auth\SourceFactory');
+            $factoryClass = \SimpleSAML\Module::resolveClass(
+                $id,
+                'Auth\Source\Factory',
+                '\SimpleSAML\Auth\SourceFactory'
+            );
 
             /** @var SourceFactory $factory */
             $factory = new $factoryClass;
             $authSource = $factory->create($info, $config);
-        } catch (Exception $e) {
+        } catch (\Exception $e) {
             // If not, instantiate the Auth Source here
-            $className = SimpleSAML\Module::resolveClass($id, 'Auth_Source', 'SimpleSAML_Auth_Source');
+            $className = \SimpleSAML\Module::resolveClass($id, 'Auth\Source', '\SimpleSAML\Auth\Source');
             $authSource = new $className($info, $config);
         }
 
@@ -333,9 +337,9 @@ abstract class SimpleSAML_Auth_Source
      * @param string      $authId The authentication source identifier.
      * @param string|NULL $type The type of authentication source. If NULL, any type will be accepted.
      *
-     * @return SimpleSAML_Auth_Source|NULL The AuthSource object, or NULL if no authentication
+     * @return Source|NULL The AuthSource object, or NULL if no authentication
      *     source with the given identifier is found.
-     * @throws SimpleSAML_Error_Exception If no such authentication source is found or it is invalid.
+     * @throws \SimpleSAML\Error\Exception If no such authentication source is found or it is invalid.
      */
     public static function getById($authId, $type = null)
     {
@@ -343,12 +347,12 @@ abstract class SimpleSAML_Auth_Source
         assert($type === null || is_string($type));
 
         // for now - load and parse config file
-        $config = SimpleSAML_Configuration::getConfig('authsources.php');
+        $config = \SimpleSAML\Configuration::getConfig('authsources.php');
 
         $authConfig = $config->getArray($authId, null);
         if ($authConfig === null) {
             if ($type !== null) {
-                throw new SimpleSAML_Error_Exception(
+                throw new \SimpleSAML\Error\Exception(
                     'No authentication source with id '.
                     var_export($authId, true).' found.'
                 );
@@ -363,7 +367,7 @@ abstract class SimpleSAML_Auth_Source
         }
 
         // the authentication source doesn't have the correct type
-        throw new SimpleSAML_Error_Exception(
+        throw new \SimpleSAML\Error\Exception(
             'Invalid type of authentication source '.
             var_export($authId, true).'. Was '.var_export(get_class($ret), true).
             ', should be '.var_export($type, true).'.'
@@ -379,13 +383,13 @@ abstract class SimpleSAML_Auth_Source
     public static function logoutCallback($state)
     {
         assert(is_array($state));
-        assert(array_key_exists('SimpleSAML_Auth_Source.logoutSource', $state));
+        assert(array_key_exists('\SimpleSAML\Auth\Source.logoutSource', $state));
 
-        $source = $state['SimpleSAML_Auth_Source.logoutSource'];
+        $source = $state['\SimpleSAML\Auth\Source.logoutSource'];
 
-        $session = SimpleSAML_Session::getSessionFromRequest();
+        $session = \SimpleSAML\Session::getSessionFromRequest();
         if (!$session->isValid($source)) {
-            SimpleSAML\Logger::warning(
+            \SimpleSAML\Logger::warning(
                 'Received logout from an invalid authentication source '.
                 var_export($source, true)
             );
@@ -422,22 +426,22 @@ abstract class SimpleSAML_Auth_Source
         if (array_key_exists('LogoutCallbackState', $state)) {
             $callbackState = $state['LogoutCallbackState'];
         } else {
-            $callbackState = array();
+            $callbackState = [];
         }
 
         $id = strlen($this->authId).':'.$this->authId.$assoc;
 
-        $data = array(
+        $data = [
             'callback' => $callback,
             'state'    => $callbackState,
-        );
+        ];
 
-        $session = SimpleSAML_Session::getSessionFromRequest();
+        $session = \SimpleSAML\Session::getSessionFromRequest();
         $session->setData(
-            'SimpleSAML_Auth_Source.LogoutCallbacks',
+            '\SimpleSAML\Auth\Source.LogoutCallbacks',
             $id,
             $data,
-            SimpleSAML_Session::DATA_TIMEOUT_SESSION_END
+            \SimpleSAML\Session::DATA_TIMEOUT_SESSION_END
         );
     }
 
@@ -458,9 +462,9 @@ abstract class SimpleSAML_Auth_Source
 
         $id = strlen($this->authId).':'.$this->authId.$assoc;
 
-        $session = SimpleSAML_Session::getSessionFromRequest();
+        $session = \SimpleSAML\Session::getSessionFromRequest();
 
-        $data = $session->getData('SimpleSAML_Auth_Source.LogoutCallbacks', $id);
+        $data = $session->getData('\SimpleSAML\Auth\Source.LogoutCallbacks', $id);
         if ($data === null) {
             // FIXME: fix for IdP-first flow (issue 397) -> reevaluate logout callback infrastructure
             $session->doLogout($this->authId);
@@ -475,7 +479,7 @@ abstract class SimpleSAML_Auth_Source
         $callback = $data['callback'];
         $callbackState = $data['state'];
 
-        $session->deleteData('SimpleSAML_Auth_Source.LogoutCallbacks', $id);
+        $session->deleteData('\SimpleSAML\Auth\Source.LogoutCallbacks', $id);
         call_user_func($callback, $callbackState);
     }
 
@@ -487,7 +491,7 @@ abstract class SimpleSAML_Auth_Source
      */
     public static function getSources()
     {
-        $config = SimpleSAML_Configuration::getOptionalConfig('authsources.php');
+        $config = \SimpleSAML\Configuration::getOptionalConfig('authsources.php');
 
         return $config->getOptions();
     }
@@ -499,12 +503,12 @@ abstract class SimpleSAML_Auth_Source
      * @param array $source An array with the auth source configuration.
      * @param string $id The auth source identifier.
      *
-     * @throws Exception If the first element of $source is not an identifier for the auth source.
+     * @throws \Exception If the first element of $source is not an identifier for the auth source.
      */
     protected static function validateSource($source, $id)
     {
         if (!array_key_exists(0, $source) || !is_string($source[0])) {
-            throw new Exception(
+            throw new \Exception(
                 'Invalid authentication source \''.$id.
                 '\': First element must be a string which identifies the authentication source.'
             );
