@@ -9,6 +9,7 @@
 namespace SimpleSAML\Bindings\Shib13;
 
 use SAML2\DOMDocumentFactory;
+use SimpleSAML\Error;
 use SimpleSAML\Utils\Config;
 use SimpleSAML\Utils\HTTP;
 use SimpleSAML\Utils\Random;
@@ -18,7 +19,6 @@ use SimpleSAML\Utils\XML;
 
 class Artifact
 {
-
     /**
      * Parse the query string, and extract the SAMLart parameters.
      *
@@ -33,7 +33,7 @@ class Artifact
 
         // We need to process the query string manually, to capture all SAMLart parameters
 
-        $artifacts = array();
+        $artifacts = [];
 
         $elements = explode('&', $_SERVER['QUERY_STRING']);
         foreach ($elements as $element) {
@@ -58,20 +58,20 @@ class Artifact
      */
     private static function buildRequest(array $artifacts)
     {
-        $msg = '<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/">' .
-            '<SOAP-ENV:Body>' .
-            '<samlp:Request xmlns:samlp="urn:oasis:names:tc:SAML:1.0:protocol"' .
-            ' RequestID="' . Random::generateID() . '"' .
-            ' MajorVersion="1" MinorVersion="1"' .
-            ' IssueInstant="' . Time::generateTimestamp() . '"' .
+        $msg = '<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/">'.
+            '<SOAP-ENV:Body>'.
+            '<samlp:Request xmlns:samlp="urn:oasis:names:tc:SAML:1.0:protocol"'.
+            ' RequestID="'.Random::generateID().'"'.
+            ' MajorVersion="1" MinorVersion="1"'.
+            ' IssueInstant="'.Time::generateTimestamp().'"'.
             '>';
 
         foreach ($artifacts as $a) {
-            $msg .= '<samlp:AssertionArtifact>' . htmlspecialchars($a) . '</samlp:AssertionArtifact>';
+            $msg .= '<samlp:AssertionArtifact>'.htmlspecialchars($a).'</samlp:AssertionArtifact>';
         }
 
-        $msg .= '</samlp:Request>' .
-            '</SOAP-ENV:Body>' .
+        $msg .= '</samlp:Request>'.
+            '</SOAP-ENV:Body>'.
             '</SOAP-ENV:Envelope>';
 
         return $msg;
@@ -83,7 +83,7 @@ class Artifact
      *
      * @param string $soapResponse The SOAP response.
      * @return string The <saml1p:Response> element, as a string.
-     * @throws \SimpleSAML_Error_Exception
+     * @throws Error\Exception
      */
     private static function extractResponse($soapResponse)
     {
@@ -92,24 +92,24 @@ class Artifact
         try {
             $doc = DOMDocumentFactory::fromString($soapResponse);
         } catch (\Exception $e) {
-            throw new \SimpleSAML_Error_Exception('Error parsing SAML 1 artifact response.');
+            throw new Error\Exception('Error parsing SAML 1 artifact response.');
         }
 
         $soapEnvelope = $doc->firstChild;
         if (!XML::isDOMNodeOfType($soapEnvelope, 'Envelope', 'http://schemas.xmlsoap.org/soap/envelope/')) {
-            throw new \SimpleSAML_Error_Exception('Expected artifact response to contain a <soap:Envelope> element.');
+            throw new Error\Exception('Expected artifact response to contain a <soap:Envelope> element.');
         }
 
         $soapBody = XML::getDOMChildren($soapEnvelope, 'Body', 'http://schemas.xmlsoap.org/soap/envelope/');
         if (count($soapBody) === 0) {
-            throw new \SimpleSAML_Error_Exception('Couldn\'t find <soap:Body> in <soap:Envelope>.');
+            throw new Error\Exception('Couldn\'t find <soap:Body> in <soap:Envelope>.');
         }
         $soapBody = $soapBody[0];
 
 
         $responseElement = XML::getDOMChildren($soapBody, 'Response', 'urn:oasis:names:tc:SAML:1.0:protocol');
         if (count($responseElement) === 0) {
-            throw new \SimpleSAML_Error_Exception('Couldn\'t find <saml1p:Response> in <soap:Body>.');
+            throw new Error\Exception('Couldn\'t find <saml1p:Response> in <soap:Body>.');
         }
         $responseElement = $responseElement[0];
 
@@ -128,19 +128,22 @@ class Artifact
     /**
      * This function receives a SAML 1.1 artifact.
      *
-     * @param \SimpleSAML_Configuration $spMetadata The metadata of the SP.
-     * @param \SimpleSAML_Configuration $idpMetadata The metadata of the IdP.
+     * @param \SimpleSAML\Configuration $spMetadata The metadata of the SP.
+     * @param \SimpleSAML\Configuration $idpMetadata The metadata of the IdP.
      * @return string The <saml1p:Response> element, as an XML string.
-     * @throws \SimpleSAML_Error_Exception
+     * @throws Error\Exception
      */
-    public static function receive(\SimpleSAML_Configuration $spMetadata, \SimpleSAML_Configuration $idpMetadata)
+    public static function receive(\SimpleSAML\Configuration $spMetadata, \SimpleSAML\Configuration $idpMetadata)
     {
         $artifacts = self::getArtifacts();
         $request = self::buildRequest($artifacts);
 
         XML::debugSAMLMessage($request, 'out');
 
-        $url = $idpMetadata->getDefaultEndpoint('ArtifactResolutionService', array('urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding'));
+        $url = $idpMetadata->getDefaultEndpoint(
+            'ArtifactResolutionService',
+            ['urn:oasis:names:tc:SAML:1.0:bindings:SOAP-binding']
+        );
         $url = $url['Location'];
 
         $peerPublicKeys = $idpMetadata->getPublicKeys('signing', true);
@@ -149,33 +152,33 @@ class Artifact
             if ($key['type'] !== 'X509Certificate') {
                 continue;
             }
-            $certData .= "-----BEGIN CERTIFICATE-----\n" .
-                chunk_split($key['X509Certificate'], 64) .
+            $certData .= "-----BEGIN CERTIFICATE-----\n".
+                chunk_split($key['X509Certificate'], 64).
                 "-----END CERTIFICATE-----\n";
         }
 
-        $file = System::getTempDir() . DIRECTORY_SEPARATOR . sha1($certData) . '.crt';
+        $file = System::getTempDir().DIRECTORY_SEPARATOR.sha1($certData).'.crt';
         if (!file_exists($file)) {
             System::writeFile($file, $certData);
         }
 
         $spKeyCertFile = Config::getCertPath($spMetadata->getString('privatekey'));
 
-        $opts = array(
-            'ssl' => array(
+        $opts = [
+            'ssl' => [
                 'verify_peer' => true,
                 'cafile' => $file,
                 'local_cert' => $spKeyCertFile,
                 'capture_peer_cert' => true,
                 'capture_peer_chain' => true,
-            ),
-            'http' => array(
+            ],
+            'http' => [
                 'method' => 'POST',
                 'content' => $request,
-                'header' => 'SOAPAction: http://www.oasis-open.org/committees/security' . "\r\n" .
+                'header' => 'SOAPAction: http://www.oasis-open.org/committees/security'."\r\n".
                     'Content-Type: text/xml',
-            ),
-        );
+            ],
+        ];
 
         // Fetch the artifact
         $response = HTTP::fetch($url, $opts);
