@@ -1,5 +1,6 @@
 <?php
 
+namespace SimpleSAML;
 
 /**
  * This file implements functions to read and write to a group of memcache
@@ -17,22 +18,22 @@
  * @author Olav Morken, UNINETT AS.
  * @package SimpleSAMLphp
  */
-class SimpleSAML_Memcache
-{
 
+class Memcache
+{
     /**
      * Cache of the memcache servers we are using.
      *
-     * @var Memcache[]|null
+     * @var \Memcache[]|null
      */
     private static $serverGroups = null;
 
 
-  /**
-   * The flavor of memcache PHP extension we are using.
-   *
-   * @var string
-   */
+    /**
+     * The flavor of memcache PHP extension we are using.
+     *
+     * @var string
+     */
     private static $extension = '';
 
 
@@ -45,7 +46,7 @@ class SimpleSAML_Memcache
      */
     public static function get($key)
     {
-        SimpleSAML\Logger::debug("loading key $key from memcache");
+        Logger::debug("loading key $key from memcache");
 
         $latestInfo = null;
         $latestTime = 0.0;
@@ -59,7 +60,7 @@ class SimpleSAML_Memcache
             if ($serializedInfo === false) {
                 // either the server is down, or we don't have the value stored on that server
                 $mustUpdate = true;
-                $up = $server->getstats();
+                $up = $server->getStats();
                 if ($up !== false) {
                     $allDown = false;
                 }
@@ -76,19 +77,19 @@ class SimpleSAML_Memcache
              * - 'data': The data.
              */
             if (!is_array($info)) {
-                SimpleSAML\Logger::warning(
+                Logger::warning(
                     'Retrieved invalid data from a memcache server. Data was not an array.'
                 );
                 continue;
             }
             if (!array_key_exists('timestamp', $info)) {
-                SimpleSAML\Logger::warning(
+                Logger::warning(
                     'Retrieved invalid data from a memcache server. Missing timestamp.'
                 );
                 continue;
             }
             if (!array_key_exists('data', $info)) {
-                SimpleSAML\Logger::warning(
+                Logger::warning(
                     'Retrieved invalid data from a memcache server. Missing data.'
                 );
                 continue;
@@ -121,17 +122,17 @@ class SimpleSAML_Memcache
         if ($latestData === null) {
             if ($allDown) {
                 // all servers are down, panic!
-                $e = new SimpleSAML_Error_Error('MEMCACHEDOWN', null, 503);
-                throw new SimpleSAML_Error_Exception('All memcache servers are down', 503, $e);
+                $e = new Error\Error('MEMCACHEDOWN', null, 503);
+                throw new Error\Exception('All memcache servers are down', 503, $e);
             }
             // we didn't find any data matching the key
-            SimpleSAML\Logger::debug("key $key not found in memcache");
+            Logger::debug("key $key not found in memcache");
             return null;
         }
 
         if ($mustUpdate) {
             // we found data matching the key, but some of the servers need updating
-            SimpleSAML\Logger::debug("Memcache servers out of sync for $key, forcing sync");
+            Logger::debug("Memcache servers out of sync for $key, forcing sync");
             self::set($key, $latestData);
         }
 
@@ -148,11 +149,11 @@ class SimpleSAML_Memcache
      */
     public static function set($key, $value, $expire = null)
     {
-        SimpleSAML\Logger::debug("saving key $key to memcache");
-        $savedInfo = array(
+        Logger::debug("saving key $key to memcache");
+        $savedInfo = [
             'timestamp' => microtime(true),
             'data'      => $value
-        );
+        ];
 
         if ($expire === null) {
             $expire = self::getExpireTime();
@@ -162,7 +163,7 @@ class SimpleSAML_Memcache
 
         // store this object to all groups of memcache servers
         foreach (self::getMemcacheServers() as $server) {
-            if (self::$extension === 'memcached') {
+            if (self::$extension === '\memcached') {
                 $server->set($key, $savedInfoSerialized, $expire);
             } else {
                 $server->set($key, $savedInfoSerialized, 0, $expire);
@@ -179,7 +180,7 @@ class SimpleSAML_Memcache
     public static function delete($key)
     {
         assert(is_string($key));
-        SimpleSAML\Logger::debug("deleting key $key from memcache");
+        Logger::debug("deleting key $key from memcache");
 
         // store this object to all groups of memcache servers
         foreach (self::getMemcacheServers() as $server) {
@@ -206,16 +207,16 @@ class SimpleSAML_Memcache
      *    The timeout for contacting this server, in seconds.
      *    The default value is 3 seconds.
      *
-     * @param Memcache $memcache The Memcache object we should add this server to.
+     * @param \Memcache $memcache The Memcache object we should add this server to.
      * @param array    $server An associative array with the configuration options for the server to add.
      *
-     * @throws Exception If any configuration option for the server is invalid.
+     * @throws \Exception If any configuration option for the server is invalid.
      */
     private static function addMemcacheServer($memcache, $server)
     {
         // the hostname option is required
         if (!array_key_exists('hostname', $server)) {
-            throw new Exception(
+            throw new \Exception(
                 "hostname setting missing from server in the 'memcache_store.servers' configuration option."
             );
         }
@@ -224,27 +225,21 @@ class SimpleSAML_Memcache
 
         // the hostname must be a valid string
         if (!is_string($hostname)) {
-            throw new Exception(
+            throw new \Exception(
                 "Invalid hostname for server in the 'memcache_store.servers' configuration option. The hostname is".
                 ' supposed to be a string.'
             );
         }
 
-        // check if we are told to use a socket
-        $socket = false;
-        if (strpos($hostname, 'unix:///') === 0) {
-            $socket = true;
-        }
-
         // check if the user has specified a port number
-        if ($socket) {
+        if (strpos($hostname, 'unix:///') === 0) {
             // force port to be 0 for sockets
             $port = 0;
         } elseif (array_key_exists('port', $server)) {
             // get the port number from the array, and validate it
             $port = (int) $server['port'];
             if (($port <= 0) || ($port > 65535)) {
-                throw new Exception(
+                throw new \Exception(
                     "Invalid port for server in the 'memcache_store.servers' configuration option. The port number".
                     ' is supposed to be an integer between 0 and 65535.'
                 );
@@ -263,7 +258,7 @@ class SimpleSAML_Memcache
             // get the weight and validate it
             $weight = (int) $server['weight'];
             if ($weight <= 0) {
-                throw new Exception(
+                throw new \Exception(
                     "Invalid weight for server in the 'memcache_store.servers' configuration option. The weight is".
                     ' supposed to be a positive integer.'
                 );
@@ -278,7 +273,7 @@ class SimpleSAML_Memcache
             // get the timeout and validate it
             $timeout = (int) $server['timeout'];
             if ($timeout <= 0) {
-                throw new Exception(
+                throw new \Exception(
                     "Invalid timeout for server in the 'memcache_store.servers' configuration option. The timeout is".
                     ' supposed to be a positive integer.'
                 );
@@ -289,7 +284,7 @@ class SimpleSAML_Memcache
         }
 
         // add this server to the Memcache object
-        if (self::$extension === 'memcached') {
+        if (self::$extension === '\memcached') {
             $memcache->addServer($hostname, $port);
         } else {
             $memcache->addServer($hostname, $port, true, $weight, $timeout, $timeout, true);
@@ -303,26 +298,28 @@ class SimpleSAML_Memcache
      *
      * @param array $group Array of servers which should be created as a group.
      *
-     * @return Memcache A Memcache object of the servers in the group
+     * @return \Memcache A Memcache object of the servers in the group
      *
-     * @throws Exception If the servers configuration is invalid.
+     * @throws \Exception If the servers configuration is invalid.
      */
     private static function loadMemcacheServerGroup(array $group)
     {
-        $class = class_exists('Memcache') ? 'Memcache' : (class_exists('Memcached') ? 'Memcached' : false);
+        $class = class_exists('\Memcache') ? '\Memcache' : (class_exists('\Memcached') ? '\Memcached' : false);
         if (!$class) {
-            throw new Exception('Missing Memcached implementation. You must install either the Memcache or Memcached extension.');
+            throw new \Exception(
+                'Missing Memcached implementation. You must install either the Memcache or Memcached extension.'
+            );
         }
         self::$extension = strtolower($class);
 
-        // create the Memcache object
+        // create the \Memcache object
         $memcache = new $class();
 
         // iterate over all the servers in the group and add them to the Memcache object
         foreach ($group as $index => $server) {
             // make sure that we don't have an index. An index would be a sign of invalid configuration
             if (!is_int($index)) {
-                throw new Exception(
+                throw new \Exception(
                     "Invalid index on element in the 'memcache_store.servers' configuration option. Perhaps you".
                     ' have forgotten to add an array(...) around one of the server groups? The invalid index was: '.
                     $index
@@ -331,7 +328,7 @@ class SimpleSAML_Memcache
 
             // make sure that the server object is an array. Each server is an array with name-value pairs
             if (!is_array($server)) {
-                throw new Exception(
+                throw new \Exception(
                     'Invalid value for the server with index '.$index.
                     '. Remeber that the \'memcache_store.servers\' configuration option'.
                     ' contains an array of arrays of arrays.'
@@ -349,9 +346,9 @@ class SimpleSAML_Memcache
      * This function gets a list of all configured memcache servers. This list is initialized based
      * on the content of 'memcache_store.servers' in the configuration.
      *
-     * @return Memcache[] Array with Memcache objects.
+     * @return \Memcache[] Array with Memcache objects.
      *
-     * @throws Exception If the servers configuration is invalid.
+     * @throws \Exception If the servers configuration is invalid.
      */
     private static function getMemcacheServers()
     {
@@ -361,10 +358,10 @@ class SimpleSAML_Memcache
         }
 
         // initialize the servers-array
-        self::$serverGroups = array();
+        self::$serverGroups = [];
 
         // load the configuration
-        $config = SimpleSAML_Configuration::getInstance();
+        $config = Configuration::getInstance();
 
 
         $groups = $config->getArray('memcache_store.servers');
@@ -373,7 +370,7 @@ class SimpleSAML_Memcache
         foreach ($groups as $index => $group) {
             // make sure that the group doesn't have an index. An index would be a sign of invalid configuration
             if (!is_int($index)) {
-                throw new Exception(
+                throw new \Exception(
                     "Invalid index on element in the 'memcache_store.servers'".
                     ' configuration option. Perhaps you have forgotten to add an array(...)'.
                     ' around one of the server groups? The invalid index was: '.$index
@@ -385,7 +382,7 @@ class SimpleSAML_Memcache
              * an array of name => value pairs for that server.
              */
             if (!is_array($group)) {
-                throw new Exception(
+                throw new \Exception(
                     "Invalid value for the server with index ".$index.
                     ". Remeber that the 'memcache_store.servers' configuration option".
                     ' contains an array of arrays of arrays.'
@@ -410,20 +407,20 @@ class SimpleSAML_Memcache
      *
      * @return integer The value which should be passed in the set(...) calls to the memcache objects.
      *
-     * @throws Exception If the option 'memcache_store.expires' has a negative value.
+     * @throws \Exception If the option 'memcache_store.expires' has a negative value.
      */
     private static function getExpireTime()
     {
         // get the configuration instance
-        $config = SimpleSAML_Configuration::getInstance();
-        assert($config instanceof SimpleSAML_Configuration);
+        $config = Configuration::getInstance();
+        assert($config instanceof \SimpleSAML\Configuration);
 
         // get the expire-value from the configuration
         $expire = $config->getInteger('memcache_store.expires', 0);
 
         // it must be a positive integer
         if ($expire < 0) {
-            throw new Exception(
+            throw new \Exception(
                 "The value of 'memcache_store.expires' in the configuration can't be a negative integer."
             );
         }
@@ -438,9 +435,7 @@ class SimpleSAML_Memcache
         /* The expire option is given as the number of seconds into the future an item should expire. We convert this
          * to an actual timestamp.
          */
-        $expireTime = time() + $expire;
-
-        return $expireTime;
+        return (time() + $expire);
     }
 
 
@@ -449,21 +444,21 @@ class SimpleSAML_Memcache
      *
      * @return array Array with the names of each stat and an array with the value for each server group.
      *
-     * @throws Exception If memcache server status couldn't be retrieved.
+     * @throws \Exception If memcache server status couldn't be retrieved.
      */
     public static function getStats()
     {
-        $ret = array();
+        $ret = [];
 
         foreach (self::getMemcacheServers() as $sg) {
             $stats = method_exists($sg, 'getExtendedStats') ? $sg->getExtendedStats() : $sg->getStats();
             foreach ($stats as $server => $data) {
                 if ($data === false) {
-                    throw new Exception('Failed to get memcache server status.');
+                    throw new \Exception('Failed to get memcache server status.');
                 }
             }
 
-            $stats = SimpleSAML\Utils\Arrays::transpose($stats);
+            $stats = Utils\Arrays::transpose($stats);
 
             $ret = array_merge_recursive($ret, $stats);
         }
@@ -480,7 +475,7 @@ class SimpleSAML_Memcache
      */
     public static function getRawStats()
     {
-        $ret = array();
+        $ret = [];
 
         foreach (self::getMemcacheServers() as $sg) {
             $stats = method_exists($sg, 'getExtendedStats') ? $sg->getExtendedStats() : $sg->getStats();
