@@ -1,5 +1,6 @@
 <?php
 
+namespace SimpleSAML\Metadata;
 
 /**
  * This class implements a metadata source which loads metadata from XML files.
@@ -8,7 +9,8 @@
  * @author Olav Morken, UNINETT AS.
  * @package SimpleSAMLphp
  */
-class SimpleSAML_Metadata_MetaDataStorageHandlerXML extends SimpleSAML_Metadata_MetaDataStorageSource
+
+class MetaDataStorageHandlerXML extends MetaDataStorageSource
 {
 
     /**
@@ -35,29 +37,29 @@ class SimpleSAML_Metadata_MetaDataStorageHandlerXML extends SimpleSAML_Metadata_
         $src = $srcXml = null;
         if (array_key_exists('file', $config)) {
             // get the configuration
-            $globalConfig = SimpleSAML_Configuration::getInstance();
+            $globalConfig = \SimpleSAML\Configuration::getInstance();
             $src = $globalConfig->resolvePath($config['file']);
         } elseif (array_key_exists('url', $config)) {
             $src = $config['url'];
         } elseif (array_key_exists('xml', $config)) {
             $srcXml = $config['xml'];
         } else {
-            throw new Exception("Missing one of 'file', 'url' and 'xml' in XML metadata source configuration.");
+            throw new \Exception("Missing one of 'file', 'url' and 'xml' in XML metadata source configuration.");
         }
 
 
-        $SP1x = array();
-        $IdP1x = array();
-        $SP20 = array();
-        $IdP20 = array();
-        $AAD = array();
+        $SP1x = [];
+        $IdP1x = [];
+        $SP20 = [];
+        $IdP20 = [];
+        $AAD = [];
 
-        if(isset($src)) {
-            $entities = SimpleSAML_Metadata_SAMLParser::parseDescriptorsFile($src);
-        } elseif(isset($srcXml)) {
-            $entities = SimpleSAML_Metadata_SAMLParser::parseDescriptorsString($srcXml);
+        if (isset($src)) {
+            $entities = SAMLParser::parseDescriptorsFile($src);
+        } elseif (isset($srcXml)) {
+            $entities = SAMLParser::parseDescriptorsString($srcXml);
         } else {
-            throw new Exception("Neither source file path/URI nor string data provided");
+            throw new \Exception("Neither source file path/URI nor string data provided");
         }
         foreach ($entities as $entityId => $entity) {
             $md = $entity->getMetadata1xSP();
@@ -86,13 +88,13 @@ class SimpleSAML_Metadata_MetaDataStorageHandlerXML extends SimpleSAML_Metadata_
             }
         }
 
-        $this->metadata = array(
+        $this->metadata = [
             'shib13-sp-remote'          => $SP1x,
             'shib13-idp-remote'         => $IdP1x,
             'saml20-sp-remote'          => $SP20,
             'saml20-idp-remote'         => $IdP20,
             'attributeauthority-remote' => $AAD,
-        );
+        ];
     }
 
 
@@ -111,6 +113,6 @@ class SimpleSAML_Metadata_MetaDataStorageHandlerXML extends SimpleSAML_Metadata_
         }
 
         // we don't have this metadata set
-        return array();
+        return [];
     }
 }
