@@ -1,5 +1,9 @@
 <?php
 
+namespace SimpleSAML\Metadata;
+
+use RobRichards\XMLSecLibs\XMLSecurityKey;
+use RobRichards\XMLSecLibs\XMLSecurityDSig;
 
 /**
  * This class implements a helper function for signing of metadata.
@@ -7,16 +11,16 @@
  * @author Olav Morken, UNINETT AS.
  * @package SimpleSAMLphp
  */
-class SimpleSAML_Metadata_Signer
-{
 
+class Signer
+{
     /**
      * This functions finds what key & certificate files should be used to sign the metadata
      * for the given entity.
      *
-     * @param SimpleSAML_Configuration $config Our SimpleSAML_Configuration instance.
-     * @param array                    $entityMetadata The metadata of the entity.
-     * @param string                   $type A string which describes the type entity this is, e.g. 'SAML 2 IdP' or
+     * @param \SimpleSAML\Configuration $config Our \SimpleSAML\Configuration instance.
+     * @param array                     $entityMetadata The metadata of the entity.
+     * @param string                    $type A string which describes the type entity this is, e.g. 'SAML 2 IdP' or
      *     'Shib 1.3 SP'.
      *
      * @return array An associative array with the keys 'privatekey', 'certificate', and optionally 'privatekey_pass'.
@@ -31,7 +35,7 @@ class SimpleSAML_Metadata_Signer
             if (!array_key_exists('metadata.sign.privatekey', $entityMetadata)
                 || !array_key_exists('metadata.sign.certificate', $entityMetadata)
             ) {
-                throw new Exception(
+                throw new \Exception(
                     'Missing either the "metadata.sign.privatekey" or the'.
                     ' "metadata.sign.certificate" configuration option in the metadata for'.
                     ' the '.$type.' "'.$entityMetadata['entityid'].'". If one of'.
@@ -39,10 +43,10 @@ class SimpleSAML_Metadata_Signer
                 );
             }
 
-            $ret = array(
+            $ret = [
                 'privatekey'  => $entityMetadata['metadata.sign.privatekey'],
                 'certificate' => $entityMetadata['metadata.sign.certificate']
-            );
+            ];
 
             if (array_key_exists('metadata.sign.privatekey_pass', $entityMetadata)) {
                 $ret['privatekey_pass'] = $entityMetadata['metadata.sign.privatekey_pass'];
@@ -56,14 +60,14 @@ class SimpleSAML_Metadata_Signer
         $certificate = $config->getString('metadata.sign.certificate', null);
         if ($privatekey !== null || $certificate !== null) {
             if ($privatekey === null || $certificate === null) {
-                throw new Exception(
+                throw new \Exception(
                     'Missing either the "metadata.sign.privatekey" or the'.
                     ' "metadata.sign.certificate" configuration option in the global'.
                     ' configuration. If one of these options is specified, then the other'.
                     ' must also be specified.'
                 );
             }
-            $ret = array('privatekey' => $privatekey, 'certificate' => $certificate);
+            $ret = ['privatekey' => $privatekey, 'certificate' => $certificate];
 
             $privatekey_pass = $config->getString('metadata.sign.privatekey_pass', null);
             if ($privatekey_pass !== null) {
@@ -80,7 +84,7 @@ class SimpleSAML_Metadata_Signer
             if (!array_key_exists('privatekey', $entityMetadata)
                 || !array_key_exists('certificate', $entityMetadata)
             ) {
-                throw new Exception(
+                throw new \Exception(
                     'Both the "privatekey" and the "certificate" option must'.
                     ' be set in the metadata for the '.$type.' "'.
                     $entityMetadata['entityid'].'" before it is possible to sign metadata'.
@@ -88,10 +92,10 @@ class SimpleSAML_Metadata_Signer
                 );
             }
 
-            $ret = array(
+            $ret = [
                 'privatekey'  => $entityMetadata['privatekey'],
                 'certificate' => $entityMetadata['certificate']
-            );
+            ];
 
             if (array_key_exists('privatekey_pass', $entityMetadata)) {
                 $ret['privatekey_pass'] = $entityMetadata['privatekey_pass'];
@@ -100,7 +104,7 @@ class SimpleSAML_Metadata_Signer
             return $ret;
         }
 
-        throw new Exception(
+        throw new \Exception(
             'Could not find what key & certificate should be used to sign the metadata'.
             ' for the '.$type.' "'.$entityMetadata['entityid'].'".'
         );
@@ -110,20 +114,20 @@ class SimpleSAML_Metadata_Signer
     /**
      * Determine whether metadata signing is enabled for the given metadata.
      *
-     * @param SimpleSAML_Configuration $config Our SimpleSAML_Configuration instance.
-     * @param array                    $entityMetadata The metadata of the entity.
-     * @param string                   $type A string which describes the type entity this is, e.g. 'SAML 2 IdP' or
+     * @param \SimpleSAML\Configuration $config Our \SimpleSAML\Configuration instance.
+     * @param array                     $entityMetadata The metadata of the entity.
+     * @param string                    $type A string which describes the type entity this is, e.g. 'SAML 2 IdP' or
      *     'Shib 1.3 SP'.
      *
      * @return boolean True if metadata signing is enabled, false otherwise.
-     * @throws Exception If the value of the 'metadata.sign.enable' option is not a boolean.
+     * @throws \Exception If the value of the 'metadata.sign.enable' option is not a boolean.
      */
     private static function isMetadataSigningEnabled($config, $entityMetadata, $type)
     {
         // first check the metadata for the entity
         if (array_key_exists('metadata.sign.enable', $entityMetadata)) {
             if (!is_bool($entityMetadata['metadata.sign.enable'])) {
-                throw new Exception(
+                throw new \Exception(
                     'Invalid value for the "metadata.sign.enable" configuration option for'.
                     ' the '.$type.' "'.$entityMetadata['entityid'].'". This option'.
                     ' should be a boolean.'
@@ -145,7 +149,7 @@ class SimpleSAML_Metadata_Signer
      * This method will look for the 'metadata.sign.algorithm' key in the $entityMetadata array, or look for such
      * a configuration option in the $config object.
      *
-     * @param SimpleSAML_Configuration $config The global configuration.
+     * @param \SimpleSAML\Configuration $config The global configuration.
      * @param array $entityMetadata An array containing the metadata related to this entity.
      * @param string $type A string describing the type of entity. E.g. 'SAML 2 IdP' or 'Shib 1.3 SP'.
      *
@@ -169,12 +173,12 @@ class SimpleSAML_Metadata_Signer
             $alg = $config->getString('metadata.sign.algorithm', XMLSecurityKey::RSA_SHA256);
         }
 
-        $supported_algs = array(
+        $supported_algs = [
             XMLSecurityKey::RSA_SHA1,
             XMLSecurityKey::RSA_SHA256,
             XMLSecurityKey::RSA_SHA384,
             XMLSecurityKey::RSA_SHA512,
-        );
+        ];
 
         if (!in_array($alg, $supported_algs, true)) {
             throw new \SimpleSAML\Error\CriticalConfigurationError("Unknown signature algorithm '$alg'");
@@ -194,10 +198,10 @@ class SimpleSAML_Metadata_Signer
                 $digest = XMLSecurityDSig::SHA1;
         }
 
-        return array(
+        return [
             'algorithm' => $alg,
             'digest' => $digest,
-        );
+        ];
     }
 
 
@@ -209,11 +213,11 @@ class SimpleSAML_Metadata_Signer
      * @param string $type A string which describes the type entity this is, e.g. 'SAML 2 IdP' or 'Shib 1.3 SP'.
      *
      * @return string The $metadataString with the signature embedded.
-     * @throws Exception If the certificate or private key cannot be loaded, or the metadata doesn't parse properly.
+     * @throws \Exception If the certificate or private key cannot be loaded, or the metadata doesn't parse properly.
      */
     public static function sign($metadataString, $entityMetadata, $type)
     {
-        $config = SimpleSAML_Configuration::getInstance();
+        $config = \SimpleSAML\Configuration::getInstance();
 
         // check if metadata signing is enabled
         if (!self::isMetadataSigningEnabled($config, $entityMetadata, $type)) {
@@ -225,13 +229,15 @@ class SimpleSAML_Metadata_Signer
 
         $keyFile = \SimpleSAML\Utils\Config::getCertPath($keyCertFiles['privatekey']);
         if (!file_exists($keyFile)) {
-            throw new Exception('Could not find private key file ['.$keyFile.'], which is needed to sign the metadata');
+            throw new \Exception(
+                'Could not find private key file ['.$keyFile.'], which is needed to sign the metadata'
+            );
         }
         $keyData = file_get_contents($keyFile);
 
         $certFile = \SimpleSAML\Utils\Config::getCertPath($keyCertFiles['certificate']);
         if (!file_exists($certFile)) {
-            throw new Exception(
+            throw new \Exception(
                 'Could not find certificate file ['.$certFile.'], which is needed to sign the metadata'
             );
         }
@@ -241,14 +247,14 @@ class SimpleSAML_Metadata_Signer
         // convert the metadata to a DOM tree
         try {
             $xml = \SAML2\DOMDocumentFactory::fromString($metadataString);
-        } catch (Exception $e) {
-            throw new Exception('Error parsing self-generated metadata.');
+        } catch (\Exception $e) {
+            throw new \Exception('Error parsing self-generated metadata.');
         }
 
         $signature_cf = self::getMetadataSigningAlgorithm($config, $entityMetadata, $type);
 
         // load the private key
-        $objKey = new XMLSecurityKey($signature_cf['algorithm'], array('type' => 'private'));
+        $objKey = new XMLSecurityKey($signature_cf['algorithm'], ['type' => 'private']);
         if (array_key_exists('privatekey_pass', $keyCertFiles)) {
             $objKey->passphrase = $keyCertFiles['privatekey_pass'];
         }
@@ -263,10 +269,10 @@ class SimpleSAML_Metadata_Signer
         $objXMLSecDSig->setCanonicalMethod(XMLSecurityDSig::EXC_C14N);
 
         $objXMLSecDSig->addReferenceList(
-            array($rootNode),
+            [$rootNode],
             $signature_cf['digest'],
-            array('http://www.w3.org/2000/09/xmldsig#enveloped-signature', XMLSecurityDSig::EXC_C14N),
-            array('id_name' => 'ID')
+            ['http://www.w3.org/2000/09/xmldsig#enveloped-signature', XMLSecurityDSig::EXC_C14N],
+            ['id_name' => 'ID']
         );
 
         $objXMLSecDSig->sign($objKey);
