@@ -1,5 +1,6 @@
 <?php
 
+namespace SimpleSAML;
 
 /**
  * Misc static functions that is used several places.in example parsing and id generation.
@@ -9,9 +10,9 @@
  *
  * @deprecated This entire class will be removed in SimpleSAMLphp 2.0.
  */
-class SimpleSAML_Utilities
-{
 
+class Utilities
+{
     /**
      * @deprecated This property will be removed in SSP 2.0. Please use SimpleSAML\Logger::isErrorMasked() instead.
      */
@@ -112,11 +113,11 @@ class SimpleSAML_Utilities
 
 
     /**
-     * @deprecated This method will be removed in SSP 2.0. Please use SimpleSAML_Auth_State::parseStateID() instead.
+     * @deprecated This method will be removed in SSP 2.0. Please use \SimpleSAML\Auth\State::parseStateID() instead.
      */
     public static function parseStateID($stateId)
     {
-        return SimpleSAML_Auth_State::parseStateID($stateId);
+        return \SimpleSAML\Auth\State::parseStateID($stateId);
     }
 
 
@@ -149,7 +150,7 @@ class SimpleSAML_Utilities
      */
     public static function generateID()
     {
-        return SimpleSAML\Utils\Random::generateID();
+        return \SimpleSAML\Utils\Random::generateID();
     }
 
 
@@ -159,7 +160,7 @@ class SimpleSAML_Utilities
      */
     public static function generateTimestamp($instant = null)
     {
-        return SimpleSAML\Utils\Time::generateTimestamp($instant);
+        return \SimpleSAML\Utils\Time::generateTimestamp($instant);
     }
 
 
@@ -168,16 +169,16 @@ class SimpleSAML_Utilities
      */
     public static function parseDuration($duration, $timestamp = null)
     {
-        return SimpleSAML\Utils\Time::parseDuration($duration, $timestamp);
+        return \SimpleSAML\Utils\Time::parseDuration($duration, $timestamp);
     }
 
 
     /**
-     * @deprecated This method will be removed in SSP 2.0. Please raise a SimpleSAML_Error_Error exception instead.
+     * @deprecated This method will be removed in SSP 2.0. Please raise a SimpleSAML\Error\Error exception instead.
      */
-    public static function fatalError($trackId = 'na', $errorCode = null, Exception $e = null)
+    public static function fatalError($trackId = 'na', $errorCode = null, \Exception $e = null)
     {
-        throw new SimpleSAML_Error_Error($errorCode, $e);
+        throw new \SimpleSAML\Error\Error($errorCode, $e);
     }
 
 
@@ -186,11 +187,11 @@ class SimpleSAML_Utilities
      */
     public static function ipCIDRcheck($cidr, $ip = null)
     {
-        return SimpleSAML\Utils\Net::ipCIDRcheck($cidr, $ip);
+        return \SimpleSAML\Utils\Net::ipCIDRcheck($cidr, $ip);
     }
 
 
-    private static function _doRedirect($url, $parameters = array())
+    private static function doRedirect($url, $parameters = [])
     {
         assert(is_string($url));
         assert(!empty($url));
@@ -213,7 +214,7 @@ class SimpleSAML_Utilities
         }
 
         if (strlen($url) > 2048) {
-            SimpleSAML\Logger::warning('Redirecting to a URL longer than 2048 bytes.');
+            \SimpleSAML\Logger::warning('Redirecting to a URL longer than 2048 bytes.');
         }
 
         // Set the location header
@@ -252,7 +253,7 @@ class SimpleSAML_Utilities
      * @deprecated 1.12.0 This method will be removed from the API. Instead, use the redirectTrustedURL() or
      * redirectUntrustedURL() functions accordingly.
      */
-    public static function redirect($url, $parameters = array(), $allowed_redirect_hosts = null)
+    public static function redirect($url, $parameters = [], $allowed_redirect_hosts = null)
     {
         assert(is_string($url));
         assert(strlen($url) > 0);
@@ -263,7 +264,7 @@ class SimpleSAML_Utilities
         } else {
             $url = self::normalizeURL($url);
         }
-        self::_doRedirect($url, $parameters);
+        self::doRedirect($url, $parameters);
     }
 
 
@@ -271,7 +272,7 @@ class SimpleSAML_Utilities
      * @deprecated This method will be removed in SSP 2.0. Please use SimpleSAML\Utils\HTTP::redirectTrustedURL()
      *     instead.
      */
-    public static function redirectTrustedURL($url, $parameters = array())
+    public static function redirectTrustedURL($url, $parameters = [])
     {
         \SimpleSAML\Utils\HTTP::redirectTrustedURL($url, $parameters);
     }
@@ -281,7 +282,7 @@ class SimpleSAML_Utilities
      * @deprecated This method will be removed in SSP 2.0. Please use SimpleSAML\Utils\HTTP::redirectUntrustedURL()
      *     instead.
      */
-    public static function redirectUntrustedURL($url, $parameters = array())
+    public static function redirectUntrustedURL($url, $parameters = [])
     {
         \SimpleSAML\Utils\HTTP::redirectUntrustedURL($url, $parameters);
     }
@@ -292,7 +293,7 @@ class SimpleSAML_Utilities
      */
     public static function transposeArray($in)
     {
-        return SimpleSAML\Utils\Arrays::transpose($in);
+        return \SimpleSAML\Utils\Arrays::transpose($in);
     }
 
 
@@ -300,18 +301,18 @@ class SimpleSAML_Utilities
      * @deprecated This method will be removed in SSP 2.0. Please use SimpleSAML\Utils\XML::isDOMNodeOfType()
      *     instead.
      */
-    public static function isDOMElementOfType(DOMNode $element, $name, $nsURI)
+    public static function isDOMElementOfType(\DOMNode $element, $name, $nsURI)
     {
-        return SimpleSAML\Utils\XML::isDOMNodeOfType($element, $name, $nsURI);
+        return \SimpleSAML\Utils\XML::isDOMNodeOfType($element, $name, $nsURI);
     }
 
 
     /**
      * @deprecated This method will be removed in SSP 2.0. Please use SimpleSAML\Utils\XML::getDOMChildren() instead.
      */
-    public static function getDOMChildren(DOMElement $element, $localName, $namespaceURI)
+    public static function getDOMChildren(\DOMElement $element, $localName, $namespaceURI)
     {
-        return SimpleSAML\Utils\XML::getDOMChildren($element, $localName, $namespaceURI);
+        return \SimpleSAML\Utils\XML::getDOMChildren($element, $localName, $namespaceURI);
     }
 
 
@@ -320,7 +321,7 @@ class SimpleSAML_Utilities
      */
     public static function getDOMText($element)
     {
-        return SimpleSAML\Utils\XML::getDOMText($element);
+        return \SimpleSAML\Utils\XML::getDOMText($element);
     }
 
 
@@ -419,7 +420,7 @@ class SimpleSAML_Utilities
      */
     public static function parseAttributes($attributes)
     {
-        return SimpleSAML\Utils\Attributes::normalizeAttributesArray($attributes);
+        return \SimpleSAML\Utils\Attributes::normalizeAttributesArray($attributes);
     }
 
 
@@ -428,7 +429,7 @@ class SimpleSAML_Utilities
      */
     public static function getSecretSalt()
     {
-        return SimpleSAML\Utils\Config::getSecretSalt();
+        return \SimpleSAML\Utils\Config::getSecretSalt();
     }
 
 
@@ -463,27 +464,27 @@ class SimpleSAML_Utilities
     /**
      * @deprecated This method will be removed in SSP 2.0. Please use SimpleSAML\Utils\Crypto::loadPublicKey() instead.
      */
-    public static function loadPublicKey(SimpleSAML_Configuration $metadata, $required = false, $prefix = '')
+    public static function loadPublicKey(\SimpleSAML\Configuration $metadata, $required = false, $prefix = '')
     {
-        return SimpleSAML\Utils\Crypto::loadPublicKey($metadata, $required, $prefix);
+        return \SimpleSAML\Utils\Crypto::loadPublicKey($metadata, $required, $prefix);
     }
 
 
     /**
      * @deprecated This method will be removed in SSP 2.0. Please use SimpleSAML\Utils\Crypto::loadPrivateKey() instead.
      */
-    public static function loadPrivateKey(SimpleSAML_Configuration $metadata, $required = false, $prefix = '')
+    public static function loadPrivateKey(\SimpleSAML\Configuration $metadata, $required = false, $prefix = '')
     {
-        return SimpleSAML\Utils\Crypto::loadPrivateKey($metadata, $required, $prefix);
+        return \SimpleSAML\Utils\Crypto::loadPrivateKey($metadata, $required, $prefix);
     }
 
 
     /**
      * @deprecated This method will be removed in SSP 2.0. Please use SimpleSAML\Utils\XML::formatDOMElement() instead.
      */
-    public static function formatDOMElement(DOMElement $root, $indentBase = '')
+    public static function formatDOMElement(\DOMElement $root, $indentBase = '')
     {
-        SimpleSAML\Utils\XML::formatDOMElement($root, $indentBase);
+        \SimpleSAML\Utils\XML::formatDOMElement($root, $indentBase);
     }
 
 
@@ -492,7 +493,7 @@ class SimpleSAML_Utilities
      */
     public static function formatXMLString($xml, $indentBase = '')
     {
-        return SimpleSAML\Utils\XML::formatXMLString($xml, $indentBase);
+        return \SimpleSAML\Utils\XML::formatXMLString($xml, $indentBase);
     }
 
 
@@ -501,7 +502,7 @@ class SimpleSAML_Utilities
      */
     public static function arrayize($data, $index = 0)
     {
-        return SimpleSAML\Utils\Arrays::arrayize($data, $index);
+        return \SimpleSAML\Utils\Arrays::arrayize($data, $index);
     }
 
 
@@ -510,7 +511,7 @@ class SimpleSAML_Utilities
      */
     public static function isAdmin()
     {
-        return SimpleSAML\Utils\Auth::isAdmin();
+        return \SimpleSAML\Utils\Auth::isAdmin();
     }
 
 
@@ -519,7 +520,7 @@ class SimpleSAML_Utilities
      */
     public static function getAdminLoginURL($returnTo = null)
     {
-        return SimpleSAML\Utils\Auth::getAdminLoginURL($returnTo);
+        return \SimpleSAML\Utils\Auth::getAdminLoginURL($returnTo);
     }
 
 
@@ -560,18 +561,18 @@ class SimpleSAML_Utilities
         assert(is_string($destination));
         assert(is_array($post));
 
-        $postId = SimpleSAML\Utils\Random::generateID();
-        $postData = array(
+        $postId = \SimpleSAML\Utils\Random::generateID();
+        $postData = [
             'post' => $post,
             'url'  => $destination,
-        );
+        ];
 
-        $session = SimpleSAML_Session::getSessionFromRequest();
+        $session = \SimpleSAML\Session::getSessionFromRequest();
         $session->setData('core_postdatalink', $postId, $postData);
 
-        $redirInfo = base64_encode(SimpleSAML\Utils\Crypto::aesEncrypt($session->getSessionId().':'.$postId));
+        $redirInfo = base64_encode(\SimpleSAML\Utils\Crypto::aesEncrypt($session->getSessionId().':'.$postId));
 
-        $url = SimpleSAML\Module::getModuleURL('core/postredirect.php', array('RedirInfo' => $redirInfo));
+        $url = \SimpleSAML\Module::getModuleURL('core/postredirect.php', ['RedirInfo' => $redirInfo]);
         $url = preg_replace("#^https:#", "http:", $url);
 
         return $url;
@@ -610,7 +611,7 @@ class SimpleSAML_Utilities
      */
     public static function getTempDir()
     {
-        return SimpleSAML\Utils\System::getTempDir();
+        return \SimpleSAML\Utils\System::getTempDir();
     }
 
 
@@ -619,7 +620,7 @@ class SimpleSAML_Utilities
      */
     public static function maskErrors($mask)
     {
-        SimpleSAML\Logger::maskErrors($mask);
+        \SimpleSAML\Logger::maskErrors($mask);
     }
 
 
@@ -628,7 +629,7 @@ class SimpleSAML_Utilities
      */
     public static function popErrorMask()
     {
-        SimpleSAML\Logger::popErrorMask();
+        \SimpleSAML\Logger::popErrorMask();
     }
 
 
@@ -664,7 +665,7 @@ class SimpleSAML_Utilities
     /**
      * @deprecated This method will be removed in SSP 2.0. Please use SimpleSAML\Utils\HTTP::fetch() instead.
      */
-    public static function fetch($path, $context = array(), $getHeaders = false)
+    public static function fetch($path, $context = [], $getHeaders = false)
     {
         return \SimpleSAML\Utils\HTTP::fetch($path, $context, $getHeaders);
     }
@@ -675,7 +676,7 @@ class SimpleSAML_Utilities
      */
     public static function aesEncrypt($clear)
     {
-        return SimpleSAML\Utils\Crypto::aesEncrypt($clear);
+        return \SimpleSAML\Utils\Crypto::aesEncrypt($clear);
     }
 
 
@@ -684,7 +685,7 @@ class SimpleSAML_Utilities
      */
     public static function aesDecrypt($encData)
     {
-        return SimpleSAML\Utils\Crypto::aesDecrypt($encData);
+        return \SimpleSAML\Utils\Crypto::aesDecrypt($encData);
     }
 
 
@@ -693,7 +694,7 @@ class SimpleSAML_Utilities
      */
     public static function isWindowsOS()
     {
-        return SimpleSAML\Utils\System::getOS() === SimpleSAML\Utils\System::WINDOWS;
+        return \SimpleSAML\Utils\System::getOS() === \SimpleSAML\Utils\System::WINDOWS;
     }
 
 
