@@ -23,7 +23,7 @@ class Arrays
      */
     public static function arrayize($data, $index = 0)
     {
-        return (is_array($data)) ? $data : array($index => $data);
+        return (is_array($data)) ? $data : [$index => $data];
     }
 
 
@@ -42,7 +42,7 @@ class Arrays
             return false;
         }
 
-        $ret = array();
+        $ret = [];
         foreach ($array as $k1 => $a2) {
             if (!is_array($a2)) {
                 return false;
@@ -50,7 +50,7 @@ class Arrays
 
             foreach ($a2 as $k2 => $v) {
                 if (!array_key_exists($k2, $ret)) {
-                    $ret[$k2] = array();
+                    $ret[$k2] = [];
                 }
                 $ret[$k2][$k1] = $v;
             }
