@@ -16,11 +16,10 @@ use LibXMLError;
 
 class Errors
 {
-
     /**
      * @var array This is an stack of error logs. The topmost element is the one we are currently working on.
      */
-    private static $errorStack = array();
+    private static $errorStack = [];
 
     /**
      * @var bool This is the xml error state we had before we began logging.
@@ -67,7 +66,7 @@ class Errors
         }
 
         // Add a new level to the error stack
-        self::$errorStack[] = array();
+        self::$errorStack[] = [];
     }
 
 
@@ -82,7 +81,7 @@ class Errors
         // Check whether the error access functions are present
         if (!function_exists('libxml_use_internal_errors')) {
             // Pretend that no errors occurred
-            return array();
+            return [];
         }
 
         // Add any errors which may have occurred
@@ -111,8 +110,8 @@ class Errors
     public static function formatError($error)
     {
         assert($error instanceof LibXMLError);
-        return 'level=' . $error->level . ',code='  . $error->code . ',line=' . $error->line . ',col=' . $error->column .
-            ',msg=' . trim($error->message);
+        return 'level='.$error->level.',code='.$error->code.',line='.$error->line.',col='.$error->column.
+            ',msg='.trim($error->message);
     }
 
 
@@ -132,7 +131,7 @@ class Errors
 
         $ret = '';
         foreach ($errors as $error) {
-            $ret .= self::formatError($error) . "\n";
+            $ret .= self::formatError($error)."\n";
         }
 
         return $ret;
