@@ -28,7 +28,7 @@ class Parser
         // Traverse all existing namespaces in element
         $namespaces = $element->getNamespaces();
         foreach ($namespaces as $prefix => $ns) {
-            $element[(($prefix === '') ? 'xmlns' : 'xmlns:' . $prefix)] = $ns;
+            $element[(($prefix === '') ? 'xmlns' : 'xmlns:'.$prefix)] = $ns;
         }
         
         /* Create a new parser with the xml document where the namespace definitions
@@ -52,7 +52,9 @@ class Parser
         $result = $this->simplexml->xpath($xpath);
         if (!is_array($result) || empty($result)) {
             if ($required) {
-                throw new \Exception('Could not get value from XML document using the following XPath expression: ' . $xpath);
+                throw new \Exception(
+                    'Could not get value from XML document using the following XPath expression: '.$xpath
+                );
             } else {
                 return null;
             }
@@ -69,7 +71,9 @@ class Parser
             }
         }
         if ($required) {
-            throw new \Exception('Could not get value from XML document using multiple alternative XPath expressions.');
+            throw new \Exception(
+                'Could not get value from XML document using multiple alternative XPath expressions.'
+            );
         } else {
             return null;
         }
