@@ -11,7 +11,8 @@
 // SSP is loaded as a separate project
 if (file_exists(dirname(dirname(__FILE__)).'/vendor/autoload.php')) {
     require_once dirname(dirname(__FILE__)).'/vendor/autoload.php';
-} else {  // SSP is loaded as a library
+} else {
+    // SSP is loaded as a library
     if (file_exists(dirname(dirname(__FILE__)).'/../../autoload.php')) {
         require_once dirname(dirname(__FILE__)).'/../../autoload.php';
     } else {
