@@ -20,9 +20,11 @@
 function temporaryLoader($class)
 {
     // handle the upgrade to the latest version of XMLSecLibs using namespaces
-    if (strstr($class, 'XMLSec')) {
-        if (class_exists('\\RobRichards\\XMLSecLibs\\'.$class, true)) {
-            class_alias('\\RobRichards\\XMLSecLibs\\'.$class, $class);
+    if (strstr($class, 'XMLSec') && !strstr($class, '\\RobRichards\\XMLSecLibs\\')) {
+        $new = '\\RobRichards\\XMLSecLibs\\'.$class;
+        if (class_exists($new, true)) {
+            class_alias($new, $class);
+            SimpleSAML\Logger::warning("The class '$class' is now using namespaces, please use '$new'.");
             return;
         }
     }
@@ -33,7 +35,7 @@ function temporaryLoader($class)
     $original = $class;
 
     // list of classes that have been renamed or moved
-    $renamed = array(
+    $renamed = [
         'SimpleSAML_Metadata_MetaDataStorageHandlerMDX' => 'SimpleSAML_Metadata_Sources_MDQ',
         'SimpleSAML_Logger_LoggingHandlerSyslog' => 'SimpleSAML_Logger_SyslogLoggingHandler',
         'SimpleSAML_Logger_LoggingHandlerErrorLog' => 'SimpleSAML_Logger_ErrorLogLoggingHandler',
@@ -42,7 +44,7 @@ function temporaryLoader($class)
         'SimpleSAML_IdP_LogoutHandler' => 'SimpleSAML_IdP_LogoutHandlerInterface',
         'SimpleSAML_IdP_LogoutIFrame' => 'SimpleSAML_IdP_IFrameLogoutHandler',
         'SimpleSAML_IdP_LogoutTraditional' => 'SimpleSAML_IdP_TraditionalLogoutHandler',
-    );
+    ];
     if (array_key_exists($class, $renamed)) {
         // the class has been renamed, try to load it and create an alias
         $class = $renamed[$class];
@@ -87,9 +89,22 @@ function sspmodAutoloadPSR0($className)
         return;
     }
 
-    $modNameEnd = strpos($className, '_', $modulePrefixLength);
-    $module = substr($className, $modulePrefixLength, $modNameEnd - $modulePrefixLength);
-    $path = explode('_', substr($className, $modNameEnd + 1));
+    // list of classes that have been renamed or moved
+    $renamed = [
+        'sspmod_adfs_SAML2_XML_fed_Const' => [
+            'module' => 'adfs',
+            'path' => ['SAML2', 'XML', 'fed', 'Constants']
+        ],
+    ];
+    if (array_key_exists($className, $renamed)) {
+        // the class has been renamed, try to load it and create an alias
+        $module = $renamed[$className]['module'];
+        $path = $renamed[$className]['path'];
+    } else {
+        $modNameEnd = strpos($className, '_', $modulePrefixLength);
+        $module = substr($className, $modulePrefixLength, $modNameEnd - $modulePrefixLength);
+        $path = explode('_', substr($className, $modNameEnd + 1));
+    }
 
     if (!\SimpleSAML\Module::isModuleEnabled($module)) {
         return;
@@ -104,8 +119,8 @@ function sspmodAutoloadPSR0($className)
     if (!class_exists($className, false) && !interface_exists($className, false)) {
         // the file exists, but the class is not defined. Is it using namespaces?
         $nspath = join('\\', $path);
-        if (class_exists('SimpleSAML\Module\\'.$module.'\\'.$nspath) ||
-            interface_exists('SimpleSAML\Module\\'.$module.'\\'.$nspath)
+        if (class_exists('SimpleSAML\\Module\\'.$module.'\\'.$nspath) ||
+            interface_exists('SimpleSAML\\Module\\'.$module.'\\'.$nspath)
         ) {
             // the class has been migrated, create an alias and warn about it
             \SimpleSAML\Logger::warning(
@@ -126,7 +141,8 @@ function sspmodAutoloadPSR0($className)
 function sspmodAutoloadPSR4($className)
 {
     $elements = explode('\\', $className);
-    if ($elements[0] === '') { // class name starting with /, ignore
+    if ($elements[0] === '') {
+        // class name starting with /, ignore
         array_shift($elements);
     }
     if (count($elements) < 4) {
