@@ -1,13 +1,13 @@
 <?php
 
 if (!isset($_REQUEST['idp'])) {
-    throw new SimpleSAML_Error_BadRequest('Missing "idp" parameter.');
+    throw new \SimpleSAML\Error\BadRequest('Missing "idp" parameter.');
 }
 $idp = (string) $_REQUEST['idp'];
-$idp = SimpleSAML_IdP::getById($idp);
+$idp = \SimpleSAML\IdP::getById($idp);
 
 if (!isset($_REQUEST['association'])) {
-    throw new SimpleSAML_Error_BadRequest('Missing "association" parameter.');
+    throw new \SimpleSAML\Error\BadRequest('Missing "association" parameter.');
 }
 $assocId = urldecode($_REQUEST['association']);
 
@@ -18,15 +18,15 @@ if (isset($_REQUEST['RelayState'])) {
 
 $associations = $idp->getAssociations();
 if (!isset($associations[$assocId])) {
-    throw new SimpleSAML_Error_BadRequest('Invalid association id.');
+    throw new \SimpleSAML\Error\BadRequest('Invalid association id.');
 }
 $association = $associations[$assocId];
 
-$metadata = SimpleSAML_Metadata_MetaDataStorageHandler::getMetadataHandler();
+$metadata = \SimpleSAML\Metadata\MetaDataStorageHandler::getMetadataHandler();
 $idpMetadata = $idp->getConfig();
 $spMetadata = $metadata->getMetaDataConfig($association['saml:entityID'], 'saml20-sp-remote');
 
-$lr = sspmod_saml_Message::buildLogoutRequest($idpMetadata, $spMetadata);
+$lr = \SimpleSAML\Module\saml\Message::buildLogoutRequest($idpMetadata, $spMetadata);
 $lr->setSessionIndex($association['saml:SessionIndex']);
 $lr->setNameId($association['saml:NameID']);
 
@@ -41,15 +41,15 @@ if ($encryptNameId === null) {
     $encryptNameId = $idpMetadata->getBoolean('nameid.encryption', false);
 }
 if ($encryptNameId) {
-    $lr->encryptNameId(sspmod_saml_Message::getEncryptionKey($spMetadata));
+    $lr->encryptNameId(\SimpleSAML\Module\saml\Message::getEncryptionKey($spMetadata));
 }
 
-SimpleSAML_Stats::log('saml:idp:LogoutRequest:sent', array(
+\SimpleSAML\Stats::log('saml:idp:LogoutRequest:sent', [
     'spEntityID'  => $association['saml:entityID'],
     'idpEntityID' => $idpMetadata->getString('entityid'),
-));
+]);
 
-$bindings = array(\SAML2\Constants::BINDING_HTTP_POST);
+$bindings = [\SAML2\Constants::BINDING_HTTP_POST];
 
 $dst = $spMetadata->getDefaultEndpoint('SingleLogoutService', $bindings);
 $binding = \SAML2\Binding::getBinding($dst['Binding']);
