@@ -21,9 +21,10 @@ if (array_key_exists('continue', $_REQUEST)) {
 
 $globalConfig = \SimpleSAML\Configuration::getInstance();
 $t = new \SimpleSAML\XHTML\Template($globalConfig, 'core:short_sso_interval.php');
+$translator = $t->getTranslator();
 $t->data['target'] = \SimpleSAML\Module::getModuleURL('core/short_sso_interval.php');
 $t->data['params'] = ['StateId' => $id];
 $t->data['trackId'] = $session->getTrackID();
-$this->data['header'] = $this->t('{core:short_sso_interval:warning_header}');
-$this->data['autofocus'] = 'contbutton';
+$t->data['header'] = $translator->t('{core:short_sso_interval:warning_header}');
+$t->data['autofocus'] = 'contbutton';
 $t->show();
