@@ -11,12 +11,12 @@
 $baseDir = dirname(dirname(dirname(dirname(__FILE__))));
 
 // Add library autoloader.
-require_once($baseDir . '/lib/_autoload.php');
+require_once($baseDir.'/lib/_autoload.php');
 
 if (!SimpleSAML\Module::isModuleEnabled('cron')) {
-    echo("You need to enable the cron module before this script can be used.\n");
-    echo("You can enable it by running the following command:\n");
-    echo('  echo >"' . $baseDir . '/modules/cron/enable' . "\"\n");
+    echo "You need to enable the cron module before this script can be used.\n";
+    echo "You can enable it by running the following command:\n";
+    echo '  echo >"'.$baseDir.'/modules/cron/enable'."\"\n";
     exit(1);
 }
 
