@@ -1,5 +1,6 @@
 <?php
 
+namespace SimpleSAML\Module\discopower;
 
 /**
  * This class implements a generic IdP discovery service, for use in various IdP discovery service pages. This should
@@ -10,14 +11,13 @@
  * @author Andreas Åkre Solberg <andreas@uninett.no>, UNINETT AS.
  * @package SimpleSAMLphp
  */
-class sspmod_discopower_PowerIdPDisco extends SimpleSAML_XHTML_IdPDisco
+
+class PowerIdPDisco extends \SimpleSAML\XHTML\IdPDisco
 {
-
-
     /**
      * The configuration for this instance.
      *
-     * @var SimpleSAML_Configuration
+     * @var \SimpleSAML\Configuration
      */
     private $discoconfig;
 
@@ -51,7 +51,7 @@ class sspmod_discopower_PowerIdPDisco extends SimpleSAML_XHTML_IdPDisco
     {
         parent::__construct($metadataSets, $instance);
 
-        $this->discoconfig = SimpleSAML_Configuration::getConfig('module_discopower.php');
+        $this->discoconfig = \SimpleSAML\Configuration::getConfig('module_discopower.php');
 
         $this->cdcDomain = $this->discoconfig->getString('cdc.domain', null);
         if ($this->cdcDomain !== null && $this->cdcDomain[0] !== '.') {
@@ -72,7 +72,7 @@ class sspmod_discopower_PowerIdPDisco extends SimpleSAML_XHTML_IdPDisco
      */
     protected function log($message)
     {
-        SimpleSAML\Logger::info('PowerIdPDisco.'.$this->instance.': '.$message);
+        \SimpleSAML\Logger::info('PowerIdPDisco.'.$this->instance.': '.$message);
     }
 
 
@@ -110,24 +110,24 @@ class sspmod_discopower_PowerIdPDisco extends SimpleSAML_XHTML_IdPDisco
      */
     protected function idplistStructured($list)
     {
-        $slist = array();
+        $slist = [];
 
         $order = $this->discoconfig->getValue('taborder');
         if (is_array($order)) {
             foreach ($order as $oe) {
-                $slist[$oe] = array();
+                $slist[$oe] = [];
             }
         }
 
         $enableTabs = $this->discoconfig->getValue('tabs', null);
 
         foreach ($list as $key => $val) {
-            $tags = array('misc');
+            $tags = ['misc'];
             if (array_key_exists('tags', $val)) {
                 $tags = $val['tags'];
             }
             foreach ($tags as $tag) {
-                if (!empty($enableTabs) && !in_array($tag, $enableTabs, true)) {
+                if (!empty($enableTabs) && !in_array($tag, $enableTabs)) {
                     continue;
                 }
                 $slist[$tag][$key] = $val;
@@ -135,7 +135,7 @@ class sspmod_discopower_PowerIdPDisco extends SimpleSAML_XHTML_IdPDisco
         }
 
         foreach ($slist as $tab => $tbslist) {
-            uasort($slist[$tab], array('sspmod_discopower_PowerIdPDisco', 'mcmp'));
+            uasort($slist[$tab], ['\SimpleSAML\Module\discopower\PowerIdPDisco', 'mcmp']);
         }
 
         return $slist;
@@ -153,21 +153,21 @@ class sspmod_discopower_PowerIdPDisco extends SimpleSAML_XHTML_IdPDisco
      */
     private function processFilter($filter, $entry, $default = true)
     {
-        if (in_array($entry['entityid'], $filter['entities.include'], true)) {
+        if (in_array($entry['entityid'], $filter['entities.include'])) {
             return true;
         }
-        if (in_array($entry['entityid'], $filter['entities.exclude'], true)) {
+        if (in_array($entry['entityid'], $filter['entities.exclude'])) {
             return false;
         }
 
         if (array_key_exists('tags', $entry)) {
             foreach ($filter['tags.include'] as $fe) {
-                if (in_array($fe, $entry['tags'], true)) {
+                if (in_array($fe, $entry['tags'])) {
                     return true;
                 }
             }
             foreach ($filter['tags.exclude'] as $fe) {
-                if (in_array($fe, $entry['tags'], true)) {
+                if (in_array($fe, $entry['tags'])) {
                     return false;
                 }
             }
@@ -190,7 +190,7 @@ class sspmod_discopower_PowerIdPDisco extends SimpleSAML_XHTML_IdPDisco
 
         try {
             $spmd = $this->metadata->getMetaData($this->spEntityId, 'saml20-sp-remote');
-        } catch (Exception $e) {
+        } catch (\Exception $e) {
             return $list;
         }
 
@@ -203,27 +203,26 @@ class sspmod_discopower_PowerIdPDisco extends SimpleSAML_XHTML_IdPDisco
         $filter = $spmd['discopower.filter'];
 
         if (!array_key_exists('entities.include', $filter)) {
-            $filter['entities.include'] = array();
+            $filter['entities.include'] = [];
         }
         if (!array_key_exists('entities.exclude', $filter)) {
-            $filter['entities.exclude'] = array();
+            $filter['entities.exclude'] = [];
         }
         if (!array_key_exists('tags.include', $filter)) {
-            $filter['tags.include'] = array();
+            $filter['tags.include'] = [];
         }
         if (!array_key_exists('tags.exclude', $filter)) {
-            $filter['tags.exclude'] = array();
+            $filter['tags.exclude'] = [];
         }
 
         $defaultrule = true;
         if (array_key_exists('entities.include', $spmd['discopower.filter']) ||
             array_key_exists('tags.include', $spmd['discopower.filter'])
         ) {
-
             $defaultrule = false;
         }
 
-        $returnlist = array();
+        $returnlist = [];
         foreach ($list as $key => $entry) {
             if ($this->processFilter($filter, $entry, $defaultrule)) {
                 $returnlist[$key] = $entry;
@@ -246,44 +245,123 @@ class sspmod_discopower_PowerIdPDisco extends SimpleSAML_XHTML_IdPDisco
         $idpList = $this->getIdPList();
         $idpList = $this->idplistStructured($this->filterList($idpList));
         $preferredIdP = $this->getRecommendedIdP();
-        $faventry = NULL;
-        foreach ($idpList AS $tab => $slist) {
-            if (!empty($preferredIdP) && array_key_exists($preferredIdP, $slist)) {
-                $faventry = $slist[$preferredIdP];
-            }
-        }
 
-        $t = new SimpleSAML_XHTML_Template($this->config, 'discopower:disco.tpl.php', 'disco');
-        $discoPowerTabs = array(
-            'denmark' => $t->noop('{discopower:tabs:denmark}'),
-            'edugain' => $t->noop('{discopower:tabs:edugain}'),
-            'finland' => $t->noop('{discopower:tabs:finland}'),
-            'greece' => $t->noop('{discopower:tabs:greece}'),
-            'southafrica' => $t->noop('{discopower:tabs:southafrica}'),
-            'iceland' => $t->noop('{discopower:tabs:iceland}'),
-            'incommon' => $t->noop('{discopower:tabs:incommon}'),
-            'kalmar' => $t->noop('{discopower:tabs:kalmar}'),
-            'misc' => $t->noop('{discopower:tabs:misc}'),
-            'norway' => $t->noop('{discopower:tabs:norway}'),
-            'sweden' => $t->noop('{discopower:tabs:sweden}'),
-            'switzerland' => $t->noop('{discopower:tabs:switzerland}'),
-            'ukacessfederation' => $t->noop('{discopower:tabs:ukacessfederation}'),
-        );
-        $t->data['faventry'] = $faventry;
-        $t->data['tabNames'] = $discoPowerTabs;
-        $t->data['idplist'] = $idpList;
-        $t->data['preferredidp'] = $preferredIdP;
+        $t = new \SimpleSAML\XHTML\Template($this->config, 'discopower:disco.tpl.php', 'disco');
+        $discoPowerTabs = [
+            'denmark' => \SimpleSAML\Locale\Translate::noop('{discopower:tabs:denmark}'),
+            'edugain' => \SimpleSAML\Locale\Translate::noop('{discopower:tabs:edugain}'),
+            'finland' => \SimpleSAML\Locale\Translate::noop('{discopower:tabs:finland}'),
+            'greece' => \SimpleSAML\Locale\Translate::noop('{discopower:tabs:greece}'),
+            'southafrica' => \SimpleSAML\Locale\Translate::noop('{discopower:tabs:southafrica}'),
+            'iceland' => \SimpleSAML\Locale\Translate::noop('{discopower:tabs:iceland}'),
+            'incommon' => \SimpleSAML\Locale\Translate::noop('{discopower:tabs:incommon}'),
+            'kalmar' => \SimpleSAML\Locale\Translate::noop('{discopower:tabs:kalmar}'),
+            'misc' => \SimpleSAML\Locale\Translate::noop('{discopower:tabs:misc}'),
+            'norway' => \SimpleSAML\Locale\Translate::noop('{discopower:tabs:norway}'),
+            'sweden' => \SimpleSAML\Locale\Translate::noop('{discopower:tabs:sweden}'),
+            'switzerland' => \SimpleSAML\Locale\Translate::noop('{discopower:tabs:switzerland}'),
+            'ukacessfederation' => \SimpleSAML\Locale\Translate::noop('{discopower:tabs:ukacessfederation}'),
+        ];
+
         $t->data['return'] = $this->returnURL;
         $t->data['returnIDParam'] = $this->returnIdParam;
         $t->data['entityID'] = $this->spEntityId;
+        $t->data['defaulttab'] = $this->discoconfig->getValue('defaulttab', 0);
+
+        $idpList = $this->processMetadata($t, $idpList, $preferredIdP);
+
+        $t->data['idplist'] = $idpList;
+        foreach ($idpList as $tab => $slist) {
+            if (!empty($preferredIdP) && array_key_exists($preferredIdP, $slist)) {
+                $t->data['faventry'] = $slist[$preferredIdP];
+                break;
+            }
+        }
+
+        if (!empty($t->data['faventry'])) {
+            $t->data['autofocus'] = 'favouritesubmit';
+        }
+
+        $search = '<script type="text/javascript">
+            $(document).ready(function() {
+                $("#tabdiv").tabs({ selected: '.$t->data['defaulttab'].' });';
+        $i = 0;
+        foreach ($idpList as $tab => $slist) {
+            $search .= "\n".'$("#query_'.$tab.'").liveUpdate("#list_'.$tab.'")'.
+            (($i++ == 0) && (empty($this->data['faventry'])) ? '.focus()' : '').';';
+        }
+        $search .= "});\n</script>";
+
+        $t->data['search'] = $search;
+        $t->data['score'] = $this->discoconfig->getValue('score', 'quicksilver');
+        $t->data['tabNames'] = $discoPowerTabs;
+        $t->data['preferredidp'] = $preferredIdP;
         $t->data['urlpattern'] = htmlspecialchars(\SimpleSAML\Utils\HTTP::getSelfURLNoQuery());
         $t->data['rememberenabled'] = $this->config->getBoolean('idpdisco.enableremember', false);
         $t->data['rememberchecked'] = $this->config->getBoolean('idpdisco.rememberchecked', false);
-        $t->data['defaulttab'] = $this->discoconfig->getValue('defaulttab', 0);
-        $t->data['score'] = $this->discoconfig->getValue('score', 'quicksilver');
+        $t->data['jquery'] = ['core' => true, 'ui' => true];
         $t->show();
     }
 
+    private function processMetadata($t, $metadata, $favourite)
+    {
+        $basequerystring = '?'.
+            'entityID='.urlencode($t->data['entityID']).'&amp;'.
+            'return='.urlencode($t->data['return']).'&amp;'.
+            'returnIDParam='.urlencode($t->data['returnIDParam']).'&amp;idpentityid=';
+
+        foreach ($metadata as $tab => $idps) {
+            foreach ($idps as $entityid => $entity) {
+                $translation = false;
+
+                // Translate name
+                if (isset($entity['UIInfo']['DisplayName'])) {
+                    $displayName = $entity['UIInfo']['DisplayName'];
+
+                    // Should always be an array of language code -> translation
+                    assert(is_array($displayName));
+
+                    if (!empty($displayName)) {
+                        $translation = $t->getTranslator()->getPreferredTranslation($displayName);
+                    }
+                }
+
+                if (($translation === false) && array_key_exists('name', $entity)) {
+                    if (is_array($entity['name'])) {
+                        $translation = $t->getTranslator()->getPreferredTranslation($entity['name']);
+                    } else {
+                        $translation = $entity['name'];
+                    }
+                }
+
+                if ($translation === false) {
+                    $translation = $entity['entityid'];
+                }
+                $entity['translated'] = $translation;
+
+                // HTML output
+                if ($entity['entityid'] === $favourite) {
+                    $html = '<a class="metaentry favourite" href="'.
+                        $basequerystring.urlencode($entity['entityid']).'">';
+                } else {
+                    $html = '<a class="metaentry" href="'.
+                        $basequerystring.urlencode($entity['entityid']).'">';
+                }
+                $html .= $entity['translated'];
+                if (array_key_exists('icon', $entity) && $entity['icon'] !== null) {
+                    $iconUrl = \SimpleSAML\Utils\HTTP::resolveURL($entity['icon']);
+                    $html .= '<img alt="Icon for identity provider" class="entryicon" src="'.
+                        htmlspecialchars($iconUrl).'" />';
+                }
+                $html .= '</a>';
+                $entity['html'] = $html;
+
+                // Save processed data
+                $metadata[$tab][$entityid] = $entity;
+            }
+        }
+        return $metadata;
+    }
 
     /**
      * Get the IdP entities saved in the common domain cookie.
@@ -293,7 +371,7 @@ class sspmod_discopower_PowerIdPDisco extends SimpleSAML_XHTML_IdPDisco
     private function getCDC()
     {
         if (!isset($_COOKIE['_saml_idp'])) {
-            return array();
+            return [];
         }
 
         $ret = (string) $_COOKIE['_saml_idp'];
@@ -302,7 +380,7 @@ class sspmod_discopower_PowerIdPDisco extends SimpleSAML_XHTML_IdPDisco
             $idp = base64_decode($idp);
             if ($idp === false) {
                 // not properly base64 encoded
-                return array();
+                return [];
             }
         }
 
@@ -349,12 +427,12 @@ class sspmod_discopower_PowerIdPDisco extends SimpleSAML_XHTML_IdPDisco
             $newCookie = $tmp[1];
         }
 
-        $params = array(
+        $params = [
             'lifetime' => $this->cdcLifetime,
             'domain'   => $this->cdcDomain,
             'secure'   => true,
             'httponly' => false,
-        );
+        ];
         \SimpleSAML\Utils\HTTP::setCookie('_saml_idp', $newCookie, $params, false);
     }
 
