@@ -10,12 +10,11 @@
  */
 
 if (!isset($_REQUEST['ReturnTo'])) {
-	die('Missing ReturnTo parameter.');
+    die('Missing ReturnTo parameter.');
 }
 
 $returnTo = \SimpleSAML\Utils\HTTP::checkURLAllowed($_REQUEST['ReturnTo']);
 
-
 /*
  * The following piece of code would never be found in a real authentication page. Its
  * purpose in this example is to make this example safer in the case where the
@@ -27,9 +26,9 @@ $returnTo = \SimpleSAML\Utils\HTTP::checkURLAllowed($_REQUEST['ReturnTo']);
  */
 
 if (!preg_match('@State=(.*)@', $returnTo, $matches)) {
-	die('Invalid ReturnTo URL for this example.');
+    die('Invalid ReturnTo URL for this example.');
 }
-SimpleSAML_Auth_State::loadState(urldecode($matches[1]), 'exampleauth:External');
+\SimpleSAML\Auth\State::loadState(urldecode($matches[1]), 'exampleauth:External');
 
 /*
  * The loadState-function will not return if the second parameter does not
@@ -37,59 +36,55 @@ SimpleSAML_Auth_State::loadState(urldecode($matches[1]), 'exampleauth:External')
  * through the exampleauth:External authentication page.
  */
 
-
 /*
  * Our list of users.
  */
-$users = array(
-	'student' => array(
-		'password' => 'student',
-		'uid' => 'student',
-		'name' => 'Student Name',
-		'mail' => 'somestudent@example.org',
-		'type' => 'student',
-	),
-	'admin' => array(
-		'password' => 'admin',
-		'uid' => 'admin',
-		'name' => 'Admin Name',
-		'mail' => 'someadmin@example.org',
-		'type' => 'employee',
-	),
-);
-
+$users = [
+    'student' => [
+        'password' => 'student',
+        'uid' => 'student',
+        'name' => 'Student Name',
+        'mail' => 'somestudent@example.org',
+        'type' => 'student',
+    ],
+    'admin' => [
+        'password' => 'admin',
+        'uid' => 'admin',
+        'name' => 'Admin Name',
+        'mail' => 'someadmin@example.org',
+        'type' => 'employee',
+    ],
+];
 
 /*
  * Time to handle login responses.
  * Since this is a dummy example, we accept any data.
  */
 
-$badUserPass = FALSE;
+$badUserPass = false;
 if ($_SERVER['REQUEST_METHOD'] === 'POST') {
-	$username = (string)$_REQUEST['username'];
-	$password = (string)$_REQUEST['password'];
+    $username = (string) $_REQUEST['username'];
+    $password = (string) $_REQUEST['password'];
 
-	if (!isset($users[$username]) || $users[$username]['password'] !== $password) {
-		$badUserPass = TRUE;
-	} else {
+    if (!isset($users[$username]) || $users[$username]['password'] !== $password) {
+        $badUserPass = true;
+    } else {
+        $user = $users[$username];
 
-		$user = $users[$username];
+        if (!session_id()) {
+            // session_start not called before. Do it here.
+            session_start();
+        }
 
-		if (!session_id()) {
-			// session_start not called before. Do it here.
-			session_start();
-		}
+        $_SESSION['uid'] = $user['uid'];
+        $_SESSION['name'] = $user['name'];
+        $_SESSION['mail'] = $user['mail'];
+        $_SESSION['type'] = $user['type'];
 
-		$_SESSION['uid'] = $user['uid'];
-		$_SESSION['name'] = $user['name'];
-		$_SESSION['mail'] = $user['mail'];
-		$_SESSION['type'] = $user['type'];
-
-		\SimpleSAML\Utils\HTTP::redirectTrustedURL($returnTo);
-	}
+        \SimpleSAML\Utils\HTTP::redirectTrustedURL($returnTo);
+    }
 }
 
-
 /*
  * If we get this far, we need to show the login page to the user.
  */
@@ -101,7 +96,10 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
 </head>
 <body>
 <h1>exampleauth login page</h1>
-<p>In this example you can log in with two accounts: <code>student</code> and <code>admin</code>. In both cases, the password is the same as the username.</p>
+<p>
+In this example you can log in with two accounts: <code>student</code> and <code>admin</code>.
+In both cases, the password is the same as the username.
+</p>
 <?php if ($badUserPass) { ?>
 <p>Bad username or password.</p>
 <?php } ?>
