@@ -1,52 +1,56 @@
 <?php
-require_once(dirname(dirname(__FILE__)) . '/libextinc/OAuth.php');
+
+namespace SimpleSAML\Module\oauth;
+
+require_once(dirname(dirname(__FILE__)).'/libextinc/OAuth.php');
 
 /**
  * OAuth Store
- * 
- * Updated version, works with consumer-callbacks, certificates and 1.0-RevA protocol 
+ *
+ * Updated version, works with consumer-callbacks, certificates and 1.0-RevA protocol
  * behaviour (requestToken-callbacks and verifiers)
  *
  * @author Andreas Åkre Solberg, <andreas.solberg@uninett.no>, UNINETT AS.
  * @author Mark Dobrinic, <mdobrinic@cozmanova.com>, Cozmanova bv
  * @package SimpleSAMLphp
  */
-class sspmod_oauth_OAuthStore extends OAuthDataStore
+
+class OAuthStore extends \OAuthDataStore
 {
     private $store;
     private $config;
     private $defaultversion = '1.0';
 
-    protected $_store_tables = array(
-        'consumers' => 'consumer = array with consumer attributes', 
+    protected $_store_tables = [
+        'consumers' => 'consumer = array with consumer attributes',
         'nonce' => 'nonce+consumer_key = -boolean-',
         'requesttorequest' => 'requestToken.key = array(version,callback,consumerKey,)',
         'authorized' => 'requestToken.key, verifier = array(authenticated-user-attributes)',
         'access' => 'accessToken.key+consumerKey = accesstoken',
         'request' => 'requestToken.key+consumerKey = requesttoken',
-    );
+    ];
 
 
     public function __construct()
     {
-        $this->store = new sspmod_core_Storage_SQLPermanentStorage('oauth');
-        $this->config = SimpleSAML_Configuration::getOptionalConfig('module_oauth.php');
+        $this->store = new \SimpleSAML\Module\core\Storage\SQLPermanentStorage('oauth');
+        $this->config = \SimpleSAML\Configuration::getOptionalConfig('module_oauth.php');
     }
 
 
     /**
      * Attach the data to the token, and establish the Callback URL and verifier
-     * @param $requestTokenKey RequestToken that was authorized
-     * @param $data Data that is authorized and to be attached to the requestToken
+     * @param string $requestTokenKey RequestToken that was authorized
+     * @param string $data Data that is authorized and to be attached to the requestToken
      * @return array(string:url, string:verifier) ; empty verifier for 1.0-response
      */
-	public function authorize($requestTokenKey, $data)
+    public function authorize($requestTokenKey, $data)
     {
         $url = null;
 
         // See whether to remember values from the original requestToken request:
         $request_attributes = $this->store->get('requesttorequest', $requestTokenKey, '');
-        // must be there ..
+        // must be there
         if ($request_attributes['value']) {
             // establish callback to use
             if ($request_attributes['value']['callback']) {
@@ -61,38 +65,38 @@ class sspmod_oauth_OAuthStore extends OAuthDataStore
             $url = $oConsumer->callback_url;
         }
 
-        $verifier = SimpleSAML\Utils\Random::generateID();
-        $url = \SimpleSAML\Utils\HTTP::addURLParameters($url, array("oauth_verifier"=>$verifier));
+        $verifier = \SimpleSAML\Utils\Random::generateID();
+        $url = \SimpleSAML\Utils\HTTP::addURLParameters($url, ["oauth_verifier"=>$verifier]);
 
-        $this->store->set('authorized', $requestTokenKey, $verifier, $data, $this->config->getValue('requestTokenDuration', 60*30));
+        $this->store->set('authorized', $requestTokenKey, $verifier, $data, $this->config->getValue('requestTokenDuration', 1800)); //60*30=1800
 
-        return array($url, $verifier);
+        return [$url, $verifier];
     }
 
     /**
      * Perform lookup whether a given token exists in the list of authorized tokens; if a verifier is
      * passed as well, the verifier *must* match the verifier that was registered with the token<br/>
      * Note that an accessToken should never be stored with a verifier
-     * @param $requestToken
-     * @param $verifier
-     * @return unknown_type
+     * @param string $requestToken
+     * @param string $verifier
+     * @return bool
      */
     public function isAuthorized($requestToken, $verifier = '')
     {
-        SimpleSAML\Logger::info('OAuth isAuthorized(' . $requestToken . ')');
+        \SimpleSAML\Logger::info('OAuth isAuthorized('.$requestToken.')');
         return $this->store->exists('authorized', $requestToken, $verifier);
     }
 
     public function getAuthorizedData($token, $verifier = '')
     {
-        SimpleSAML\Logger::info('OAuth getAuthorizedData(' . $token . ')');
+        \SimpleSAML\Logger::info('OAuth getAuthorizedData('.$token.')');
         $data = $this->store->get('authorized', $token, $verifier);
         return $data['value'];
     }
 
     public function moveAuthorizedData($requestToken, $verifier, $accessTokenKey)
     {
-        SimpleSAML\Logger::info('OAuth moveAuthorizedData(' . $requestToken . ', ' . $accessTokenKey . ')');
+        \SimpleSAML\Logger::info('OAuth moveAuthorizedData('.$requestToken.', '.$accessTokenKey.')');
 
         // Retrieve authorizedData from authorized.requestToken (with provider verifier)
         $authorizedData = $this->getAuthorizedData($requestToken, $verifier);
@@ -102,12 +106,12 @@ class sspmod_oauth_OAuthStore extends OAuthDataStore
 
         // Add accesstoken with authorizedData to authorized store (with empty verifier)
         // accessTokenKey+consumer => accessToken is already registered in 'access'-table
-        $this->store->set('authorized', $accessTokenKey, '', $authorizedData, $this->config->getValue('accessTokenDuration', 60*60*24));
+        $this->store->set('authorized', $accessTokenKey, '', $authorizedData, $this->config->getValue('accessTokenDuration', 86400)); //60*60*24=86400
     }
 
     public function lookup_consumer($consumer_key)
     {
-        SimpleSAML\Logger::info('OAuth lookup_consumer(' . $consumer_key . ')');
+        \SimpleSAML\Logger::info('OAuth lookup_consumer('.$consumer_key.')');
         if (!$this->store->exists('consumers', $consumer_key, '')) {
             return null;
         }
@@ -119,72 +123,80 @@ class sspmod_oauth_OAuthStore extends OAuthDataStore
         }
 
         if ($consumer['value']['RSAcertificate']) {
-            return new OAuthConsumer($consumer['value']['key'], $consumer['value']['RSAcertificate'], $callback);
+            return new \OAuthConsumer($consumer['value']['key'], $consumer['value']['RSAcertificate'], $callback);
         } else {
-            return new OAuthConsumer($consumer['value']['key'], $consumer['value']['secret'], $callback);
+            return new \OAuthConsumer($consumer['value']['key'], $consumer['value']['secret'], $callback);
         }
     }
 
-    function lookup_token($consumer, $tokenType = 'default', $token)
+    public function lookup_token($consumer, $tokenType = 'default', $token)
     {
-        SimpleSAML\Logger::info('OAuth lookup_token(' . $consumer->key . ', ' . $tokenType. ',' . $token . ')');
+        \SimpleSAML\Logger::info('OAuth lookup_token('.$consumer->key.', '.$tokenType.','.$token.')');
         $data = $this->store->get($tokenType, $token, $consumer->key);
         if ($data == null) {
-            throw new Exception('Could not find token');
+            throw new \Exception('Could not find token');
         }
         return $data['value'];
     }
 
-    function lookup_nonce($consumer, $token, $nonce, $timestamp)
+    public function lookup_nonce($consumer, $token, $nonce, $timestamp)
     {
-        SimpleSAML\Logger::info('OAuth lookup_nonce(' . $consumer . ', ' . $token. ',' . $nonce . ')');
+        \SimpleSAML\Logger::info('OAuth lookup_nonce('.$consumer.', '.$token.','.$nonce.')');
         if ($this->store->exists('nonce', $nonce, $consumer->key)) {
             return true;
         }
-        $this->store->set('nonce', $nonce, $consumer->key, true, $this->config->getValue('nonceCache', 60*60*24*14));
+        $this->store->set('nonce', $nonce, $consumer->key, true, $this->config->getValue('nonceCache', 1209600)); //60*60*24*14=1209600
         return false;
     }
 
-    function new_request_token($consumer, $callback = null, $version = null)
+    public function new_request_token($consumer, $callback = null, $version = null)
     {
-        SimpleSAML\Logger::info('OAuth new_request_token(' . $consumer . ')');
+        \SimpleSAML\Logger::info('OAuth new_request_token('.$consumer.')');
 
-        $lifetime = $this->config->getValue('requestTokenDuration', 60*30); 
+        $lifetime = $this->config->getValue('requestTokenDuration', 1800); //60*30
 
-        $token = new OAuthToken(SimpleSAML\Utils\Random::generateID(), SimpleSAML\Utils\Random::generateID());
-        $token->callback = $callback;	// OAuth1.0-RevA
+        $token = new \OAuthToken(\SimpleSAML\Utils\Random::generateID(), \SimpleSAML\Utils\Random::generateID());
+        $token->callback = $callback; // OAuth1.0-RevA
         $this->store->set('request', $token->key, $consumer->key, $token, $lifetime);
 
         // also store in requestToken->key => array('callback'=>CallbackURL, 'version'=>oauth_version
-        $request_attributes = array(
-            'callback' => $callback, 
-            'version' => ($version?$version:$this->defaultversion),
+        $request_attributes = [
+            'callback' => $callback,
+            'version' => ($version ? $version : $this->defaultversion),
             'consumerKey' => $consumer->key,
-        );
+        ];
         $this->store->set('requesttorequest', $token->key, '', $request_attributes, $lifetime);
 
-        // also store in requestToken->key => Consumer->key (enables consumer-lookup during reqToken-authorization stage)
+        /* also store in requestToken->key =>
+         * Consumer->key (enables consumer-lookup during reqToken-authorization stage)
+         */
         $this->store->set('requesttoconsumer', $token->key, '', $consumer->key, $lifetime);
 
         return $token;
     }
 
-    function new_access_token($requestToken, $consumer, $verifier = null)
+    public function new_access_token($requestToken, $consumer, $verifier = null)
     {
-        SimpleSAML\Logger::info('OAuth new_access_token(' . $requestToken . ',' . $consumer . ')');
-        $accesstoken = new OAuthToken(SimpleSAML\Utils\Random::generateID(), SimpleSAML\Utils\Random::generateID());
-        $this->store->set('access', $accesstoken->key, $consumer->key, $accesstoken, $this->config->getValue('accessTokenDuration', 60*60*24) );
+        \SimpleSAML\Logger::info('OAuth new_access_token('.$requestToken.','.$consumer.')');
+        $accesstoken = new \OAuthToken(\SimpleSAML\Utils\Random::generateID(), \SimpleSAML\Utils\Random::generateID());
+        $this->store->set(
+            'access',
+            $accesstoken->key,
+            $consumer->key,
+            $accesstoken,
+            $this->config->getValue('accessTokenDuration', 86400) //60*60*24=86400
+        );
         return $accesstoken;
     }
 
     /**
      * Return OAuthConsumer-instance that a given requestToken was issued to
-     * @param $requestTokenKey
-     * @return unknown_type
+     * @param string $requestTokenKey
+     * @return mixed
      */
     public function lookup_consumer_by_requestToken($requestTokenKey)
     {
-        SimpleSAML\Logger::info('OAuth lookup_consumer_by_requestToken(' . $requestTokenKey . ')');
+        \SimpleSAML\Logger::info('OAuth lookup_consumer_by_requestToken('.$requestTokenKey.')');
         if (!$this->store->exists('requesttorequest', $requestTokenKey, '')) {
             return null;
         }
