@@ -1,14 +1,15 @@
 <?php
 
+namespace SimpleSAML\Module\saml\Auth\Process;
 
 /**
  * Authentication processing filter to create an attribute from a NameID.
  *
  * @package SimpleSAMLphp
  */
-class sspmod_saml_Auth_Process_NameIDAttribute extends SimpleSAML_Auth_ProcessingFilter
-{
 
+class NameIDAttribute extends \SimpleSAML\Auth\ProcessingFilter
+{
     /**
      * The attribute we should save the NameID in.
      *
@@ -58,13 +59,13 @@ class sspmod_saml_Auth_Process_NameIDAttribute extends SimpleSAML_Auth_Processin
      * @param string $format The format string.
      * @return array The format string broken into its individual components.
      *
-     * @throws SimpleSAML_Error_Exception if the replacement is invalid.
+     * @throws \SimpleSAML\Error\Exception if the replacement is invalid.
      */
     private static function parseFormat($format)
     {
         assert(is_string($format));
 
-        $ret = array();
+        $ret = [];
         $pos = 0;
         while (($next = strpos($format, '%', $pos)) !== false) {
             $ret[] = substr($format, $pos, $next - $pos);
@@ -81,13 +82,13 @@ class sspmod_saml_Auth_Process_NameIDAttribute extends SimpleSAML_Auth_Processin
                     $ret[] = 'SPNameQualifier';
                     break;
                 case 'V':
-                    $ret[] = 'value';
+                    $ret[] = 'Value';
                     break;
                 case '%':
                     $ret[] = '%';
                     break;
                 default:
-                    throw new SimpleSAML_Error_Exception('NameIDAttribute: Invalid replacement: "%'.$replacement.'"');
+                    throw new \SimpleSAML\Error\Exception('NameIDAttribute: Invalid replacement: "%'.$replacement.'"');
             }
 
             $pos = $next + 2;
@@ -114,17 +115,16 @@ class sspmod_saml_Auth_Process_NameIDAttribute extends SimpleSAML_Auth_Processin
         }
 
         $rep = $state['saml:sp:NameID'];
-        assert(isset($rep->value));
-
+        assert(!is_null($rep->getValue()));
         $rep->{'%'} = '%';
-        if (!isset($rep->Format)) {
-            $rep->Format = \SAML2\Constants::NAMEID_UNSPECIFIED;
+        if ($rep->getFormat() !== null) {
+            $rep->setFormat(\SAML2\Constants::NAMEID_UNSPECIFIED);
         }
-        if (!isset($rep->NameQualifier)) {
-            $rep->NameQualifier = $state['Source']['entityid'];
+        if ($rep->getNameQualifier() !== null) {
+            $rep->setNameQualifier($state['Source']['entityid']);
         }
-        if (!isset($rep->SPNameQualifier)) {
-            $rep->SPNameQualifier = $state['Destination']['entityid'];
+        if ($rep->getSPNameQualifier() !== null) {
+            $rep->setSPNameQualifier($state['Destination']['entityid']);
         }
 
         $value = '';
@@ -133,11 +133,11 @@ class sspmod_saml_Auth_Process_NameIDAttribute extends SimpleSAML_Auth_Processin
             if ($isString) {
                 $value .= $element;
             } else {
-                $value .= $rep->$element;
+                $value .= call_user_func([$rep, 'get'.$element]);
             }
             $isString = !$isString;
         }
 
-        $state['Attributes'][$this->attribute] = array($value);
+        $state['Attributes'][$this->attribute] = [$value];
     }
 }
