@@ -1,11 +1,14 @@
 <?php
 
+namespace SimpleSAML\Module\saml\IdP;
+
 /**
  * Helper class for working with persistent NameIDs stored in SQL datastore.
  *
  * @package SimpleSAMLphp
  */
-class sspmod_saml_IdP_SQLNameID
+
+class SQLNameID
 {
     /**
      * Create NameID table in SQL, if it is missing.
@@ -18,7 +21,7 @@ class sspmod_saml_IdP_SQLNameID
             return;
         }
 
-        $query = 'CREATE TABLE ' . $store->prefix . '_saml_PersistentNameID (
+        $query = 'CREATE TABLE '.$store->prefix.'_saml_PersistentNameID (
             _idp VARCHAR(256) NOT NULL,
             _sp VARCHAR(256) NOT NULL,
             _user VARCHAR(256) NOT NULL,
@@ -27,7 +30,8 @@ class sspmod_saml_IdP_SQLNameID
         )';
         $store->pdo->exec($query);
 
-        $query = 'CREATE INDEX ' . $store->prefix . '_saml_PersistentNameID_idp_sp ON '  . $store->prefix . '_saml_PersistentNameID (_idp, _sp)';
+        $query = 'CREATE INDEX '.$store->prefix.'_saml_PersistentNameID_idp_sp ON ';
+        $query .= $store->prefix.'_saml_PersistentNameID (_idp, _sp)';
         $store->pdo->exec($query);
 
         $store->setTableVersion('saml_PersistentNameID', 1);
@@ -45,7 +49,9 @@ class sspmod_saml_IdP_SQLNameID
     {
         $store = \SimpleSAML\Store::getInstance();
         if (!($store instanceof \SimpleSAML\Store\SQL)) {
-            throw new SimpleSAML_Error_Exception('SQL NameID store requires SimpleSAMLphp to be configured with a SQL datastore.');
+            throw new \SimpleSAML\Error\Exception(
+                'SQL NameID store requires SimpleSAMLphp to be configured with a SQL datastore.'
+            );
         }
 
         self::createTable($store);
@@ -72,14 +78,15 @@ class sspmod_saml_IdP_SQLNameID
 
         $store = self::getStore();
 
-        $params = array(
+        $params = [
             '_idp' => $idpEntityId,
             '_sp' => $spEntityId,
             '_user' => $user,
             '_value' => $value,
-        );
+        ];
 
-        $query = 'INSERT INTO ' . $store->prefix . '_saml_PersistentNameID (_idp, _sp, _user, _value) VALUES(:_idp, :_sp, :_user, :_value)';
+        $query = 'INSERT INTO '.$store->prefix;
+        $query .= '_saml_PersistentNameID (_idp, _sp, _user, _value) VALUES(:_idp, :_sp, :_user, :_value)';
         $query = $store->pdo->prepare($query);
         $query->execute($params);
     }
@@ -101,17 +108,18 @@ class sspmod_saml_IdP_SQLNameID
 
         $store = self::getStore();
 
-        $params = array(
+        $params = [
             '_idp' => $idpEntityId,
             '_sp' => $spEntityId,
             '_user' => $user,
-        );
+        ];
 
-        $query = 'SELECT _value FROM ' . $store->prefix . '_saml_PersistentNameID WHERE _idp = :_idp AND _sp = :_sp AND _user = :_user';
+        $query = 'SELECT _value FROM '.$store->prefix;
+        $query .= '_saml_PersistentNameID WHERE _idp = :_idp AND _sp = :_sp AND _user = :_user';
         $query = $store->pdo->prepare($query);
         $query->execute($params);
 
-        $row = $query->fetch(PDO::FETCH_ASSOC);
+        $row = $query->fetch(\PDO::FETCH_ASSOC);
         if ($row === false) {
             // No NameID found
             return null;
@@ -136,13 +144,14 @@ class sspmod_saml_IdP_SQLNameID
 
         $store = self::getStore();
 
-        $params = array(
+        $params = [
             '_idp' => $idpEntityId,
             '_sp' => $spEntityId,
             '_user' => $user,
-        );
+        ];
 
-        $query = 'DELETE FROM ' . $store->prefix . '_saml_PersistentNameID WHERE _idp = :_idp AND _sp = :_sp AND _user = :_user';
+        $query = 'DELETE FROM '.$store->prefix;
+        $query .= '_saml_PersistentNameID WHERE _idp = :_idp AND _sp = :_sp AND _user = :_user';
         $query = $store->pdo->prepare($query);
         $query->execute($params);
     }
@@ -162,17 +171,18 @@ class sspmod_saml_IdP_SQLNameID
 
         $store = self::getStore();
 
-        $params = array(
+        $params = [
             '_idp' => $idpEntityId,
             '_sp' => $spEntityId,
-        );
+        ];
 
-        $query = 'SELECT _user, _value FROM ' . $store->prefix . '_saml_PersistentNameID WHERE _idp = :_idp AND _sp = :_sp';
+        $query = 'SELECT _user, _value FROM '.$store->prefix;
+        $query .= '_saml_PersistentNameID WHERE _idp = :_idp AND _sp = :_sp';
         $query = $store->pdo->prepare($query);
         $query->execute($params);
 
-        $res = array();
-        while (($row = $query->fetch(PDO::FETCH_ASSOC)) !== false) {
+        $res = [];
+        while (($row = $query->fetch(\PDO::FETCH_ASSOC)) !== false) {
             $res[$row['_user']] = $row['_value'];
         }
 
