@@ -18,24 +18,64 @@ class LogoutStore
     private static function createLogoutTable(\SimpleSAML\Store\SQL $store)
     {
         $tableVer = $store->getTableVersion('saml_LogoutStore');
-        if ($tableVer === 2) {
+        if ($tableVer === 3) {
+            return;
+        } elseif ($tableVer === 2) {
+            // Drop old indexes
+            $query = 'ALTER TABLE '.$store->prefix.'_saml_LogoutStore DROP INDEX '.$store->prefix.'_saml_LogoutStore_nameId';
+            $store->pdo->exec($query);
+            $query = 'ALTER TABLE '.$store->prefix.'_saml_LogoutStore DROP INDEX _authSource';
+            $store->pdo->exec($query);
+
+            // Create new indexes
+            $query = 'CREATE INDEX '.$store->prefix.'_saml_LogoutStore_nameId ON ';
+            $query .= $store->prefix.'_saml_LogoutStore (_authSource(191), _nameId)';
+            $store->pdo->exec($query);
+
+            $query = 'ALTER TABLE '.$store->prefix.'_saml_LogoutStore ADD UNIQUE KEY (_authSource(191), _nameID, _sessionIndex)';
+            $store->pdo->exec($query);
+
+            $store->setTableVersion('saml_LogoutStore', 3);
             return;
         } elseif ($tableVer === 1) {
             // TableVersion 2 increased the column size to 255 which is the maximum length of a FQDN
             switch ($store->driver) {
                 case 'pgsql':
                     // This does not affect the NOT NULL constraint
-                    $query = 'ALTER TABLE '.$store->prefix.
-                        '_saml_LogoutStore ALTER COLUMN _authSource TYPE VARCHAR(255)';
+                    $update = ['ALTER TABLE '.$store->prefix.
+                        '_saml_LogoutStore ALTER COLUMN _authSource TYPE VARCHAR(255)'];
+                    break;
+                case  'sqlite':
+                    /**
+                     * TableVersion 2 increased the column size to 255 which is the maximum length of a FQDN
+                     * Because SQLite does not support field alterations, the approach is to:
+                     *     Create a new table without the proper column size
+                     *     Copy the current data to the new table
+                     *     Drop the old table
+                     *     Rename the new table correctly
+                     *     Read the index
+                     */
+                    $update = [
+                        'CREATE TABLE '.$store->prefix.'_saml_LogoutStore_new (_authSource VARCHAR(255) NOT NULL,'.
+                        '_nameId VARCHAR(40) NOT NULL, _sessionIndex VARCHAR(50) NOT NULL, _expire TIMESTAMP NOT NULL,'.
+                        '_sessionId VARCHAR(50) NOT NULL, UNIQUE (_authSource, _nameID, _sessionIndex))',
+                        'INSERT INTO '.$store->prefix.'_saml_LogoutStore_new SELECT * FROM '.$store->prefix.'_saml_LogoutStore',
+                        'DROP TABLE '.$store->prefix.'_saml_LogoutStore',
+                        'ALTER TABLE '.$store->prefix.'_saml_LogoutStore_new RENAME TO '.$store->prefix.'_saml_LogoutStore',
+                        'CREATE INDEX '.$store->prefix.'_saml_LogoutStore_expire ON '.$store->prefix.'_saml_LogoutStore (_expire)',
+                        'CREATE INDEX '.$store->prefix.'_saml_LogoutStore_nameId ON '.$store->prefix.'_saml_LogoutStore (_authSource, _nameId)'
+                    ];
                     break;
                 default:
-                    $query = 'ALTER TABLE '.$store->prefix.
-                        '_saml_LogoutStore MODIFY _authSource VARCHAR(255) NOT NULL';
+                    $update = ['ALTER TABLE '.$store->prefix.
+                        '_saml_LogoutStore MODIFY _authSource VARCHAR(255) NOT NULL'];
                     break;
             }
 
             try {
-                $store->pdo->exec($query);
+                foreach ($update as $query) {
+                    $store->pdo->exec($query);
+                }
             } catch (\Exception $e) {
                 \SimpleSAML\Logger::warning($store->pdo->errorInfo());
                 return;
@@ -50,7 +90,7 @@ class LogoutStore
             _sessionIndex VARCHAR(50) NOT NULL,
             _expire TIMESTAMP NOT NULL,
             _sessionId VARCHAR(50) NOT NULL,
-            UNIQUE (_authSource, _nameID, _sessionIndex)
+            UNIQUE (_authSource(191), _nameID, _sessionIndex)
         )';
         $store->pdo->exec($query);
 
@@ -59,10 +99,10 @@ class LogoutStore
         $store->pdo->exec($query);
 
         $query = 'CREATE INDEX '.$store->prefix.'_saml_LogoutStore_nameId ON ';
-        $query .= $store->prefix.'_saml_LogoutStore (_authSource, _nameId)';
+        $query .= $store->prefix.'_saml_LogoutStore (_authSource(191), _nameId)';
         $store->pdo->exec($query);
 
-        $store->setTableVersion('saml_LogoutStore', 2);
+        $store->setTableVersion('saml_LogoutStore', 3);
     }
 
 
