@@ -5,22 +5,24 @@
  */
 
 if (!array_key_exists('PATH_INFO', $_SERVER)) {
-    throw new SimpleSAML_Error_BadRequest('Missing authentication source ID in assertion consumer service URL');
+    throw new \SimpleSAML\Error\BadRequest('Missing authentication source ID in assertion consumer service URL');
 }
 
 $sourceId = substr($_SERVER['PATH_INFO'], 1);
-$source = SimpleSAML_Auth_Source::getById($sourceId, 'sspmod_saml_Auth_Source_SP');
+$source = \SimpleSAML\Auth\Source::getById($sourceId, '\SimpleSAML\Module\saml\Auth\Source\SP');
 $spMetadata = $source->getMetadata();
 
 try {
     $b = \SAML2\Binding::getCurrentBinding();
-} catch (Exception $e) { // TODO: look for a specific exception
+} catch (Exception $e) {
+    // TODO: look for a specific exception
     // This is dirty. Instead of checking the message of the exception, \SAML2\Binding::getCurrentBinding() should throw
-    // an specific exception when the binding is unknown, and we should capture that here
+    // a specific exception when the binding is unknown, and we should capture that here
     if ($e->getMessage() === 'Unable to find the current binding.') {
-        throw new SimpleSAML_Error_Error('ACSPARAMS', $e, 400);
+        throw new \SimpleSAML\Error\Error('ACSPARAMS', $e, 400);
     } else {
-        throw $e; // do not ignore other exceptions!
+        // do not ignore other exceptions!
+        throw $e;
     }
 }
 
@@ -30,26 +32,31 @@ if ($b instanceof \SAML2\HTTPArtifact) {
 
 $response = $b->receive();
 if (!($response instanceof \SAML2\Response)) {
-    throw new SimpleSAML_Error_BadRequest('Invalid message received to AssertionConsumerService endpoint.');
+    throw new \SimpleSAML\Error\BadRequest('Invalid message received to AssertionConsumerService endpoint.');
 }
 
-$idp = $response->getIssuer();
-if ($idp === null) {
+$issuer = $response->getIssuer();
+if ($issuer === null) {
     // no Issuer in the response. Look for an unencrypted assertion with an issuer
     foreach ($response->getAssertions() as $a) {
         if ($a instanceof \SAML2\Assertion) {
             // we found an unencrypted assertion, there should be an issuer here
-            $idp = $a->getIssuer();
+            $issuer = $a->getIssuer();
             break;
         }
     }
-    if ($idp === null) {
+    if ($issuer === null) {
         // no issuer found in the assertions
         throw new Exception('Missing <saml:Issuer> in message delivered to AssertionConsumerService.');
     }
 }
 
-$session = SimpleSAML_Session::getSessionFromRequest();
+$idp = $issuer;
+if ($issuer instanceof \SAML2\XML\saml\Issuer) {
+    $idp = $idp->getValue();
+}
+
+$session = \SimpleSAML\Session::getSessionFromRequest();
 $prevAuth = $session->getAuthData($sourceId, 'saml:sp:prevAuth');
 if ($prevAuth !== null && $prevAuth['id'] === $response->getId() && $prevAuth['issuer'] === $idp) {
     /* OK, it looks like this message has the same issuer
@@ -67,17 +74,17 @@ if ($prevAuth !== null && $prevAuth['id'] === $response->getId() && $prevAuth['i
     }
 
     SimpleSAML\Logger::info('No RelayState or ReturnURL available, cannot redirect.');
-    throw new SimpleSAML_Error_Exception('Duplicate assertion received.');
+    throw new \SimpleSAML\Error\Exception('Duplicate assertion received.');
 }
 
-$idpMetadata = array();
+$idpMetadata = [];
 
 $state = null;
 $stateId = $response->getInResponseTo();
 if (!empty($stateId)) {
     // this should be a response to a request we sent earlier
     try {
-        $state = SimpleSAML_Auth_State::loadState($stateId, 'saml:sp:sso');
+        $state = \SimpleSAML\Auth\State::loadState($stateId, 'saml:sp:sso');
     } catch (Exception $e) {
         // something went wrong,
         SimpleSAML\Logger::warning('Could not load state specified by InResponseTo: '.$e->getMessage().
@@ -89,7 +96,7 @@ if ($state) {
     // check that the authentication source is correct
     assert(array_key_exists('saml:sp:AuthId', $state));
     if ($state['saml:sp:AuthId'] !== $sourceId) {
-        throw new SimpleSAML_Error_Exception(
+        throw new \SimpleSAML\Error\Exception(
             'The authentication source id in the URL does not match the authentication source which sent the request.'
         );
     }
@@ -98,16 +105,14 @@ if ($state) {
     assert(array_key_exists('ExpectedIssuer', $state));
     if ($state['ExpectedIssuer'] !== $idp) {
         $idpMetadata = $source->getIdPMetadata($idp);
-        $idplist = $idpMetadata->getArrayize('IDPList', array());
+        $idplist = $idpMetadata->getArrayize('IDPList', []);
         if (!in_array($state['ExpectedIssuer'], $idplist, true)) {
-            throw new SimpleSAML_Error_Exception(
-                'The issuer of the response does not match to the identity provider we sent the request to.'
-            );
+            SimpleSAML\Logger::warning('The issuer of the response not match to the identity provider we sent the request to.');
         }
     }
 } else {
     // this is an unsolicited response
-    $state = array(
+    $state = [
         'saml:sp:isUnsolicited' => true,
         'saml:sp:AuthId'        => $sourceId,
         'saml:sp:RelayState'    => \SimpleSAML\Utils\HTTP::checkURLAllowed(
@@ -116,7 +121,7 @@ if ($state) {
                 $response->getRelayState()
             )
         ),
-    );
+    ];
 }
 
 SimpleSAML\Logger::debug('Received SAML2 Response from '.var_export($idp, true).'.');
@@ -126,11 +131,11 @@ if (empty($idpMetadata)) {
 }
 
 try {
-    $assertions = sspmod_saml_Message::processResponse($spMetadata, $idpMetadata, $response);
-} catch (sspmod_saml_Error $e) {
+    $assertions = \SimpleSAML\Module\saml\Message::processResponse($spMetadata, $idpMetadata, $response);
+} catch (\SimpleSAML\Module\saml\Error $e) {
     // the status of the response wasn't "success"
     $e = $e->toException();
-    SimpleSAML_Auth_State::throwException($state, $e);
+    \SimpleSAML\Auth\State::throwException($state, $e);
 }
 
 
@@ -138,17 +143,16 @@ $authenticatingAuthority = null;
 $nameId = null;
 $sessionIndex = null;
 $expire = null;
-$attributes = array();
+$attributes = [];
 $foundAuthnStatement = false;
 foreach ($assertions as $assertion) {
-
     // check for duplicate assertion (replay attack)
     $store = \SimpleSAML\Store::getInstance();
     if ($store !== false) {
         $aID = $assertion->getId();
         if ($store->get('saml.AssertionReceived', $aID) !== null) {
-            $e = new SimpleSAML_Error_Exception('Received duplicate assertion.');
-            SimpleSAML_Auth_State::throwException($state, $e);
+            $e = new \SimpleSAML\Error\Exception('Received duplicate assertion.');
+            \SimpleSAML\Auth\State::throwException($state, $e);
         }
 
         $notOnOrAfter = $assertion->getNotOnOrAfter();
@@ -184,8 +188,8 @@ foreach ($assertions as $assertion) {
 }
 
 if (!$foundAuthnStatement) {
-    $e = new SimpleSAML_Error_Exception('No AuthnStatement found in assertion(s).');
-    SimpleSAML_Auth_State::throwException($state, $e);
+    $e = new \SimpleSAML\Error\Exception('No AuthnStatement found in assertion(s).');
+    \SimpleSAML\Auth\State::throwException($state, $e);
 }
 
 if ($expire !== null) {
@@ -197,15 +201,15 @@ if ($expire !== null) {
 
 if (!empty($nameId)) {
     // register this session in the logout store
-    sspmod_saml_SP_LogoutStore::addSession($sourceId, $nameId, $sessionIndex, $logoutExpire);
+    \SimpleSAML\Module\saml\SP\LogoutStore::addSession($sourceId, $nameId, $sessionIndex, $logoutExpire);
 
     // we need to save the NameID and SessionIndex for logout
-    $logoutState = array(
+    $logoutState = [
         'saml:logout:Type'         => 'saml2',
         'saml:logout:IdP'          => $idp,
         'saml:logout:NameID'       => $nameId,
         'saml:logout:SessionIndex' => $sessionIndex,
-    );
+    ];
 
     $state['saml:sp:NameID'] = $nameId; // no need to mark it as persistent, it already is
 } else {
@@ -222,9 +226,9 @@ if (!empty($nameId)) {
      * it to the store), marking the IdP as SAML 1.0, which does not implement logout. Then we can safely log the user
      * out from the local session, skipping Single Logout upstream to the IdP.
      */
-    $logoutState = array(
+    $logoutState = [
         'saml:logout:Type'         => 'saml1',
-    );
+    ];
 }
 
 $state['LogoutState'] = $logoutState;
@@ -235,7 +239,7 @@ $state['saml:AuthnInstant'] = $assertion->getAuthnInstant();
 $state['PersistentAuthData'][] = 'saml:AuthnInstant';
 $state['saml:sp:SessionIndex'] = $sessionIndex;
 $state['PersistentAuthData'][] = 'saml:sp:SessionIndex';
-$state['saml:sp:AuthnContext'] = $assertion->getAuthnContext();
+$state['saml:sp:AuthnContext'] = $assertion->getAuthnContextClassRef();
 $state['PersistentAuthData'][] = 'saml:sp:AuthnContext';
 
 if ($expire !== null) {
@@ -243,12 +247,12 @@ if ($expire !== null) {
 }
 
 // note some information about the authentication, in case we receive the same response again
-$state['saml:sp:prevAuth'] = array(
+$state['saml:sp:prevAuth'] = [
     'id'     => $response->getId(),
     'issuer' => $idp,
-);
-if (isset($state['SimpleSAML_Auth_Source.ReturnURL'])) {
-    $state['saml:sp:prevAuth']['redirect'] = $state['SimpleSAML_Auth_Source.ReturnURL'];
+];
+if (isset($state['\SimpleSAML\Auth\Source.ReturnURL'])) {
+    $state['saml:sp:prevAuth']['redirect'] = $state['\SimpleSAML\Auth\Source.ReturnURL'];
 } elseif (isset($state['saml:sp:RelayState'])) {
     $state['saml:sp:prevAuth']['redirect'] = $state['saml:sp:RelayState'];
 }
