@@ -1,12 +1,16 @@
 <?php
+
+namespace SimpleSAML\Module\statistics\Graph;
+
 /*
- * sspmod_statistics_Graph_GoogleCharts will help you to create a Google Chart
- * using the Google Charts API. 
+ * \SimpleSAML\Module\statistics\Graph\GoogleCharts will help you to create a Google Chart
+ * using the Google Charts API.
  *
  * @author Andreas Åkre Solberg <andreas.solberg@uninett.no>
  * @package SimpleSAMLphp
  */
-class sspmod_statistics_Graph_GoogleCharts
+
+class GoogleCharts
 {
     /**
      * @var integer
@@ -40,11 +44,11 @@ class sspmod_statistics_Graph_GoogleCharts
     // t:10.0,58.0,95.0
     private function encodedata($datasets)
     {
-        $setstr = array();
+        $setstr = [];
         foreach ($datasets as $dataset) {
             $setstr[] = self::extEncode($dataset);
         }
-        return 'e:' . join(',', $setstr);
+        return 'e:'.join(',', $setstr);
     }
 
     public static function extEncode($values) // $max = 4095, $min = 0
@@ -59,68 +63,68 @@ class sspmod_statistics_Graph_GoogleCharts
                 $first = substr($extended_table, intval(($delta * $v / 100) / $size), 1);
                 $second = substr($extended_table, intval(($delta * $v / 100) % $size), 1);
                 $chardata .= "$first$second";
-            } else { 
-                $chardata .= '__'; // Value out of max range; 
-            } 
+            } else {
+                $chardata .= '__'; // Value out of max range;
+            }
         }
-        return($chardata); 
+        return $chardata;
     }
 
     /**
      * Generate a Google Charts URL which points to a generated image.
-     * More documentation on Google Charts here: 
+     * More documentation on Google Charts here:
      *   http://code.google.com/apis/chart/
      *
-     * @param $axis        Axis
-     * @param $axpis       Axis positions
-     * @param $datasets    Datasets values
-     * @param $max         Max value. Will be the topmost value on the Y-axis.
+     * @param string $axis        Axis
+     * @param string $axpis       Axis positions
+     * @param array $datasets    Datasets values
+     * @param integer $max         Max value. Will be the topmost value on the Y-axis.
      */
     public function show($axis, $axispos, $datasets, $maxes)
     {
-        $labeld = '&chxt=x,y' . '&chxr=0,0,1|1,0,' . $maxes[0];
+        $labeld = '&chxt=x,y'.'&chxr=0,0,1|1,0,'.$maxes[0];
         if (count($datasets) > 1) {
             if (count($datasets) !== count($maxes)) {
-                throw new Exception('Incorrect number of max calculations for graph plotting.');
+                throw new \Exception('Incorrect number of max calculations for graph plotting.');
             }
-            $labeld = '&chxt=x,y,r' . '&chxr=0,0,1|1,0,' . $maxes[0] . '|2,0,' . $maxes[1];
+            $labeld = '&chxt=x,y,r'.'&chxr=0,0,1|1,0,'.$maxes[0].'|2,0,'.$maxes[1];
         }
 
-        $url = 'https://chart.apis.google.com/chart?' .
+        $url = 'https://chart.apis.google.com/chart?'.
             // Dimension of graph. Default is 800x350
-            'chs=' . $this->x . 'x' . $this->y . 
+            'chs='.$this->x.'x'.$this->y.
 
             // Dateset values
-            '&chd=' . $this->encodedata($datasets) .
+            '&chd='.$this->encodedata($datasets).
 
             // Fill area...
-            '&chco=ff5c00,cca600' . 
-            '&chls=1,1,0|1,6,3' .
+            '&chco=ff5c00,cca600'.
+            '&chls=1,1,0|1,6,3'.
 
             // chart type is linechart
-            '&cht=lc' .
-            $labeld .
-            '&chxl=0:|' . $this->encodeaxis($axis) . # . $'|1:||top' .
-            '&chxp=0,' . join(',', $axispos) .
-            '&chg=' . (2400/(count($datasets[0])-1)) . ',-1,3,3';   // lines
+            '&cht=lc'.
+            $labeld.
+            '&chxl=0:|'.$this->encodeaxis($axis).#.$'|1:||top'.
+            '&chxp=0,'.join(',', $axispos).
+            '&chg='.(2400 / (count($datasets[0]) - 1)).',-1,3,3'; // lines
 
         return $url;
     }
 
     public function showPie($axis, $datasets)
     {
-        $url = 'https://chart.apis.google.com/chart?' .
+        $url = 'https://chart.apis.google.com/chart?'.
 
         // Dimension of graph. Default is 800x350
-        'chs=' . $this->x . 'x' . $this->y . 
+        'chs='.$this->x.'x'.$this->y.
 
         // Dateset values.
-        '&chd=' . $this->encodedata(array($datasets)) .
+        '&chd='.$this->encodedata([$datasets]).
 
         // chart type is linechart
-        '&cht=p' .
+        '&cht=p'.
 
-        '&chl=' . $this->encodeaxis($axis);
+        '&chl='.$this->encodeaxis($axis);
 
         return $url;
     }
@@ -133,13 +137,15 @@ class sspmod_statistics_Graph_GoogleCharts
      *
      * Here is some test code:
      * <code>
-     * 	    $foo = array(0, 2, 2.3, 2.6, 6, 10, 15, 98, 198, 256, 487, 563, 763, 801, 899, 999, 987, 198234.485, 283746);
-     *	    foreach ($foo AS $f) {
-     *	        echo '<p>' . $f . ' => ' . sspmod_statistics_Graph_GoogleCharts::roof($f);
-     *	    }
+     *      $foo = array(
+     *          0, 2, 2.3, 2.6, 6, 10, 15, 98, 198, 256, 487, 563, 763, 801, 899, 999, 987, 198234.485, 283746
+     *      );
+     *      foreach ($foo as $f) {
+     *          echo '<p>'.$f.' => '.\SimpleSAML\Module\statistics\Graph\GoogleCharts::roof($f);
+     *      }
      * </code>
-     * 
-     * @param $max    Input value.
+     *
+     * @param integer $max    Input value.
      */
     public static function roof($max)
     {
@@ -156,7 +162,7 @@ class sspmod_statistics_Graph_GoogleCharts
         }
 
         $maxGridLines = 10;
-        $candidates = array(1, 2, 5, 10, 20, 25, 50, 100);
+        $candidates = [1, 2, 5, 10, 20, 25, 50, 100];
 
         foreach ($candidates as $c) {
             if ($t / $c < $maxGridLines) {
@@ -165,5 +171,6 @@ class sspmod_statistics_Graph_GoogleCharts
                 return $target_top;
             }
         }
+        return 1;
     }
 }
