@@ -1,19 +1,23 @@
 <?php
+
+namespace SimpleSAML\Module\statistics;
+
 /*
  * @author Andreas Åkre Solberg <andreas.solberg@uninett.no>
  * @package SimpleSAMLphp
  */
-class sspmod_statistics_RatioDataset extends sspmod_statistics_StatDataset
+
+class RatioDataset extends StatDataset
 {
     public function aggregateSummary()
     {
         /**
          * Aggregate summary table from dataset. To be used in the table view.
          */
-        $this->summary = array(); 
-        $noofvalues = array();
+        $this->summary = [];
+        $noofvalues = [];
         foreach ($this->results as $slot => $res) {
-            foreach ($res AS $key => $value) {
+            foreach ($res as $key => $value) {
                 if (array_key_exists($key, $this->summary)) {
                     $this->summary[$key] += $value;
                     if ($value > 0) {
@@ -56,12 +60,12 @@ class sspmod_statistics_RatioDataset extends sspmod_statistics_StatDataset
 
     public function combine($result1, $result2)
     {
-        $combined = array();
+        $combined = [];
 
         foreach ($result2 as $tick => $val) {
-            $combined[$tick] = array();
+            $combined[$tick] = [];
             foreach ($val as $index => $num) {
-                $combined[$tick][$index] = $this->divide( 
+                $combined[$tick][$index] = $this->divide(
                     $this->ag($index, $result1[$tick]),
                     $this->ag($index, $result2[$tick])
                 );
@@ -75,4 +79,3 @@ class sspmod_statistics_RatioDataset extends sspmod_statistics_StatDataset
         return null;
     }
 }
-
