@@ -15,9 +15,9 @@ class ReduceSpillOverTest extends ClearStateTestCase
     public function testSetState()
     {
         $_SERVER['QUERY_STRING'] = 'a=b';
-        \SimpleSAML_Configuration::loadFromArray(array('a' => 'b'), '[ARRAY]', 'simplesaml');
-        $this->assertEquals('b', \SimpleSAML_Configuration::getInstance()->getString('a'));
-        putenv('SIMPLESAMLPHP_CONFIG_DIR=' . __DIR__);
+        \SimpleSAML\Configuration::loadFromArray(['a' => 'b'], '[ARRAY]', 'simplesaml');
+        $this->assertEquals('b', \SimpleSAML\Configuration::getInstance()->getString('a'));
+        putenv('SIMPLESAMLPHP_CONFIG_DIR='.__DIR__);
     }
 
     /**
@@ -29,7 +29,7 @@ class ReduceSpillOverTest extends ClearStateTestCase
         $this->assertArrayNotHasKey('QUERY_STRING', $_SERVER);
         $this->assertFalse(getenv('SIMPLESAMLPHP_CONFIG_DIR'));
         try {
-            \SimpleSAML_Configuration::getInstance();
+            \SimpleSAML\Configuration::getInstance();
             $this->fail('Expected config configured in other tests to no longer be valid');
         } catch (\SimpleSAML\Error\ConfigurationError $error) {
             // Expected error
