@@ -1,35 +1,34 @@
 <?php
 
+namespace SimpleSAML\Test\Auth;
+
 use PHPUnit\Framework\TestCase;
 
 /**
- * Tests for SimpleSAML_Auth_State
+ * Tests for \SimpleSAML\Auth\State
  */
-class Auth_StateTest extends TestCase
+class StateTest extends TestCase
 {
-
-
     /**
      * Test the getPersistentAuthData() function.
      */
     public function testGetPersistentAuthData()
     {
-
-        $mandatory = array(
-            'Attributes' => array(),
+        $mandatory = [
+            'Attributes' => [],
             'Expire' => 1234,
             'LogoutState' => 'logoutState',
             'AuthInstant' => 123456,
             'RememberMe' => true,
             'saml:sp:NameID' => 'nameID',
-        );
+        ];
 
         // check just mandatory parameters
         $state = $mandatory;
         $expected = $mandatory;
         $this->assertEquals(
             $expected,
-            SimpleSAML_Auth_State::getPersistentAuthData($state),
+            \SimpleSAML\Auth\State::getPersistentAuthData($state),
             'Mandatory state attributes did not survive as expected'.print_r($expected, true)
         );
 
@@ -39,32 +38,32 @@ class Auth_StateTest extends TestCase
         $expected = $state;
         $this->assertEquals(
             $expected,
-            SimpleSAML_Auth_State::getPersistentAuthData($state),
+            \SimpleSAML\Auth\State::getPersistentAuthData($state),
             'Some error occurred with missing mandatory parameters'
         );
 
         // check additional non-persistent parameters
-        $additional = array(
+        $additional = [
             'additional1' => 1,
             'additional2' => 2,
-        );
+        ];
         $state = array_merge($mandatory, $additional);
         $expected = $mandatory;
         $this->assertEquals(
             $expected,
-            SimpleSAML_Auth_State::getPersistentAuthData($state),
+            \SimpleSAML\Auth\State::getPersistentAuthData($state),
             'Additional parameters survived'
         );
 
         // check additional persistent parameters
-        $additional['PersistentAuthData'] = array('additional1');
+        $additional['PersistentAuthData'] = ['additional1'];
         $state = array_merge($mandatory, $additional);
         $expected = $state;
         unset($expected['additional2']);
         unset($expected['PersistentAuthData']);
         $this->assertEquals(
             $expected,
-            SimpleSAML_Auth_State::getPersistentAuthData($state),
+            \SimpleSAML\Auth\State::getPersistentAuthData($state),
             'Some error occurred with additional, persistent parameters'
         );
 
@@ -75,7 +74,7 @@ class Auth_StateTest extends TestCase
         unset($expected['PersistentAuthData']);
         $this->assertEquals(
             $expected,
-            SimpleSAML_Auth_State::getPersistentAuthData($state),
+            \SimpleSAML\Auth\State::getPersistentAuthData($state),
             'Some error occurred with additional, persistent parameters, and no mandatory ones'
         );
     }
