@@ -1,5 +1,6 @@
 <?php
-namespace SimpleSAML\Metadata;
+
+namespace SimpleSAML\Test\Metadata;
 
 use PHPUnit\Framework\TestCase;
 
@@ -8,15 +9,14 @@ use PHPUnit\Framework\TestCase;
  */
 class SAMLParserTest extends TestCase
 {
-
     /**
      * Test Registration Info is parsed
      */
     public function testRegistrationInfo()
     {
-        $expected = array(
+        $expected = [
             'registrationAuthority' => 'https://incommon.org',
-        );
+        ];
 
         $document = \SAML2\DOMDocumentFactory::fromString(
             <<<XML
@@ -32,12 +32,11 @@ XML
         );
 
 
-        $entities = \SimpleSAML_Metadata_SAMLParser::parseDescriptorsElement($document->documentElement);
+        $entities = \SimpleSAML\Metadata\SAMLParser::parseDescriptorsElement($document->documentElement);
         $this->assertArrayHasKey('theEntityID', $entities);
         // RegistrationInfo is accessible in the SP or IDP metadata accessors
         $metadata = $entities['theEntityID']->getMetadata20SP();
         $this->assertEquals($expected, $metadata['RegistrationInfo']);
-
     }
 
     /**
@@ -46,9 +45,9 @@ XML
      */
     public function testRegistrationInfoInheritance()
     {
-        $expected = array(
+        $expected = [
             'registrationAuthority' => 'https://incommon.org',
-        );
+        ];
 
         $document = \SAML2\DOMDocumentFactory::fromString(
             <<<XML
@@ -74,7 +73,7 @@ XML
 XML
         );
 
-        $entities = \SimpleSAML_Metadata_SAMLParser::parseDescriptorsElement($document->documentElement);
+        $entities = \SimpleSAML\Metadata\SAMLParser::parseDescriptorsElement($document->documentElement);
         $this->assertArrayHasKey('theEntityID', $entities);
         $this->assertArrayHasKey('subEntityId', $entities);
         // RegistrationInfo is accessible in the SP or IDP metadata accessors
@@ -116,7 +115,7 @@ XML
 XML
         );
 
-        $entities = \SimpleSAML_Metadata_SAMLParser::parseDescriptorsElement($document->documentElement);
+        $entities = \SimpleSAML\Metadata\SAMLParser::parseDescriptorsElement($document->documentElement);
         $this->assertArrayHasKey('theEntityID', $entities);
 
         $metadata = $entities['theEntityID']->getMetadata20SP();
@@ -124,11 +123,14 @@ XML
         $this->assertEquals("Example service", $metadata['name']['en']);
         $this->assertEquals("Dit is een voorbeeld voor de unittest.", $metadata['description']['nl']);
 
-        $expected_a = array("urn:mace:dir:attribute-def:eduPersonPrincipalName", "urn:mace:dir:attribute-def:mail", "urn:mace:dir:attribute-def:displayName");
-        $expected_r = array("urn:mace:dir:attribute-def:eduPersonPrincipalName");
+        $expected_a = [
+            "urn:mace:dir:attribute-def:eduPersonPrincipalName",
+            "urn:mace:dir:attribute-def:mail",
+            "urn:mace:dir:attribute-def:displayName"
+        ];
+        $expected_r = ["urn:mace:dir:attribute-def:eduPersonPrincipalName"];
 
         $this->assertEquals($expected_a, $metadata['attributes']);
         $this->assertEquals($expected_r, $metadata['attributes.required']);
     }
-
 }
