@@ -3,7 +3,7 @@
 namespace SimpleSAML\Test\Store;
 
 use PHPUnit\Framework\TestCase;
-use \SimpleSAML_Configuration as Configuration;
+use \SimpleSAML\Configuration;
 use \SimpleSAML\Store;
 
 /**
@@ -18,24 +18,24 @@ class RedisTest extends TestCase
 {
     protected function setUp()
     {
-        $this->config = array();
+        $this->config = [];
 
         $this->mocked_redis = $this->getMockBuilder('Predis\Client')
-                                   ->setMethods(array('get', 'set', 'setex', 'del', 'disconnect'))
+                                   ->setMethods(['get', 'set', 'setex', 'del', 'disconnect'])
                                    ->disableOriginalConstructor()
                                    ->getMock();
 
         $this->mocked_redis->method('get')
-                           ->will($this->returnCallback(array($this, 'getMocked')));
+                           ->will($this->returnCallback([$this, 'getMocked']));
 
         $this->mocked_redis->method('set')
-                           ->will($this->returnCallback(array($this, 'setMocked')));
+                           ->will($this->returnCallback([$this, 'setMocked']));
 
         $this->mocked_redis->method('setex')
-                           ->will($this->returnCallback(array($this, 'setexMocked')));
+                           ->will($this->returnCallback([$this, 'setexMocked']));
 
         $this->mocked_redis->method('del')
-                           ->will($this->returnCallback(array($this, 'delMocked')));
+                           ->will($this->returnCallback([$this, 'delMocked']));
 
         $nop = function () {
             return;
@@ -75,16 +75,37 @@ class RedisTest extends TestCase
      */
     public function testRedisInstance()
     {
-        $config = Configuration::loadFromArray(array(
+        $config = Configuration::loadFromArray([
             'store.type' => 'redis',
             'store.redis.prefix' => 'phpunit_',
-        ), '[ARRAY]', 'simplesaml');
+        ], '[ARRAY]', 'simplesaml');
 
         $store = Store::getInstance();
 
         $this->assertInstanceOf('SimpleSAML\Store\Redis', $store);
 
-        $this->clearInstance($config, '\SimpleSAML_Configuration');
+        $this->clearInstance($config, '\SimpleSAML\Configuration');
+        $this->clearInstance($store, '\SimpleSAML\Store');
+    }
+
+    /**
+     * @covers \SimpleSAML\Store::getInstance
+     * @covers \SimpleSAML\Store\Redis::__construct
+     * @test
+     */
+    public function testRedisInstanceWithPassword()
+    {
+        $config = Configuration::loadFromArray([
+            'store.type' => 'redis',
+            'store.redis.prefix' => 'phpunit_',
+            'store.redis.password' => 'password',
+        ], '[ARRAY]', 'simplesaml');
+
+        $store = Store::getInstance();
+
+        $this->assertInstanceOf('SimpleSAML\Store\Redis', $store);
+
+        $this->clearInstance($config, '\SimpleSAML\Configuration');
         $this->clearInstance($store, '\SimpleSAML\Store');
     }
 
