@@ -9,7 +9,6 @@
  * @package simplesamlphp/simplesamlphp
  */
 
-
 namespace SimpleSAML\Test\XML;
 
 use PHPUnit\Framework\TestCase;
@@ -51,7 +50,7 @@ class ErrorsTest extends TestCase
         $error->column = 'col';
         $error->message = ' msg ';
 
-        $errors = Errors::formatErrors(array($error, $error));
+        $errors = Errors::formatErrors([$error, $error]);
 
         $this->assertEquals(
             "level=level,code=code,line=line,col=col,msg=msg\nlevel=level,code=code,line=line,col=col,msg=msg\n",
