@@ -1,11 +1,13 @@
 <?php
 
+namespace SimpleSAML\Test\Module\core\Auth\Process;
+
 use PHPUnit\Framework\TestCase;
 
 /**
  * Test for the core:AttributeRealm filter.
  */
-class Test_Core_Auth_Process_AttributeRealm extends TestCase
+class AttributeRealmTest extends TestCase
 {
 
     /**
@@ -17,7 +19,7 @@ class Test_Core_Auth_Process_AttributeRealm extends TestCase
      */
     private static function processFilter(array $config, array $request)
     {
-        $filter = new sspmod_core_Auth_Process_AttributeRealm($config, NULL);
+        $filter = new \SimpleSAML\Module\core\Auth\Process\AttributeRealm($config, null);
         $filter->process($request);
         return $request;
     }
@@ -27,16 +29,16 @@ class Test_Core_Auth_Process_AttributeRealm extends TestCase
      */
     public function testBasic()
     {
-        $config = array(
-        );
-        $request = array(
-            'Attributes' => array(),
+        $config = [
+        ];
+        $request = [
+            'Attributes' => [],
             'UserID' => 'user2@example.org',
-        );
+        ];
         $result = self::processFilter($config, $request);
         $attributes = $result['Attributes'];
         $this->assertArrayHasKey('realm', $attributes);
-        $this->assertEquals($attributes['realm'], array('example.org'));
+        $this->assertEquals($attributes['realm'], ['example.org']);
     }
 
     /**
@@ -46,12 +48,12 @@ class Test_Core_Auth_Process_AttributeRealm extends TestCase
      */
     public function testNoUserID()
     {
-        $config = array(
-        );
-        $request = array(
-            'Attributes' => array(),
-        );
-        $result = self::processFilter($config, $request);
+        $config = [
+        ];
+        $request = [
+            'Attributes' => [],
+        ];
+        self::processFilter($config, $request);
     }
 
     /**
@@ -59,21 +61,21 @@ class Test_Core_Auth_Process_AttributeRealm extends TestCase
      */
     public function testAttributeNameConfig()
     {
-        $config = array(
+        $config = [
             'attributename' => 'schacHomeOrganization',
-        );
-        $request = array(
-            'Attributes' => array(
+        ];
+        $request = [
+            'Attributes' => [
                 'displayName' => 'Joe User',
                 'schacGender' => 9,
-            ),
+            ],
             'UserID' => 'user2@example.org',
-        );
+        ];
         $result = self::processFilter($config, $request);
         $attributes = $result['Attributes'];
         $this->assertArrayHasKey('schacHomeOrganization', $attributes);
         $this->assertArrayHasKey('displayName', $attributes);
-        $this->assertEquals($attributes['schacHomeOrganization'], array('example.org'));
+        $this->assertEquals($attributes['schacHomeOrganization'], ['example.org']);
     }
 
     /**
@@ -81,21 +83,21 @@ class Test_Core_Auth_Process_AttributeRealm extends TestCase
      */
     public function testTargetAttributeOverwritten()
     {
-        $config = array(
+        $config = [
             'attributename' => 'schacHomeOrganization',
-        );
-        $request = array(
-            'Attributes' => array(
+        ];
+        $request = [
+            'Attributes' => [
                 'displayName' => 'Joe User',
                 'schacGender' => 9,
                 'schacHomeOrganization' => 'example.com',
-            ),
+            ],
             'UserID' => 'user2@example.org',
-        );
+        ];
         $result = self::processFilter($config, $request);
         $attributes = $result['Attributes'];
         $this->assertArrayHasKey('schacHomeOrganization', $attributes);
-        $this->assertEquals($attributes['schacHomeOrganization'], array('example.org'));
+        $this->assertEquals($attributes['schacHomeOrganization'], ['example.org']);
     }
 
     /**
@@ -103,13 +105,13 @@ class Test_Core_Auth_Process_AttributeRealm extends TestCase
      */
     public function testNoAtisNoOp()
     {
-        $config = array();
-        $request = array(
-            'Attributes' => array(
+        $config = [];
+        $request = [
+            'Attributes' => [
                 'displayName' => 'Joe User',
-            ),
+            ],
             'UserID' => 'user2',
-        );
+        ];
         $result = self::processFilter($config, $request);
         $attributes = $result['Attributes'];
         $this->assertArrayNotHasKey('realm', $attributes);
@@ -120,13 +122,13 @@ class Test_Core_Auth_Process_AttributeRealm extends TestCase
      */
     public function testMultiAtisNoOp()
     {
-        $config = array();
-        $request = array(
-            'Attributes' => array(
+        $config = [];
+        $request = [
+            'Attributes' => [
                 'displayName' => 'Joe User',
-            ),
+            ],
             'UserID' => 'user2@home@example.org',
-        );
+        ];
         $result = self::processFilter($config, $request);
         $attributes = $result['Attributes'];
         $this->assertArrayNotHasKey('realm', $attributes);
